@@ -7,10 +7,12 @@ from setuptools_scm import (
 )
 
 import nox
+from nox.sessions   import Session
 
 ROOT_DIR  = Path(__file__).parent
 
 BUILD_DIR = (ROOT_DIR  / 'build')
+CNTRB_DIR = (ROOT_DIR  / 'contrib')
 DOCS_DIR  = (ROOT_DIR  / 'docs')
 DIST_DIR  = (BUILD_DIR / 'dist')
 
@@ -18,8 +20,8 @@ DIST_DIR  = (BUILD_DIR / 'dist')
 # Default sessions to run
 nox.options.sessions = (
 	'test',
-	'flake8',
-	'mypy'
+	'lint',
+	'typecheck'
 )
 
 def torii_version() -> str:
@@ -37,19 +39,37 @@ def torii_version() -> str:
 	)
 
 @nox.session(reuse_venv = True)
-def test(session: nox.Session) -> None:
+def test(session: Session) -> None:
 	out_dir = (BUILD_DIR / 'tests')
 	out_dir.mkdir(parents = True, exist_ok = True)
+	coverage = '--coverage' in session.posargs
+	codecov  = '--codecov' in session.posargs
+
+	unitest_args = ('-m', 'unittest', 'discover', '-s', str(ROOT_DIR))
 
 	session.install('.')
+	if coverage:
+		session.log('Coverage support enabled')
+		session.install('coverage')
+		coverage_args = (
+			'-m', 'coverage', 'run',
+			f'--rcfile={CNTRB_DIR / "coveragerc"}'
+		)
+	else:
+		coverage_args = ()
+	if codecov and coverage:
+		session.log('Codecov support enabled')
+		session.install('codecov')
+
 	session.chdir(str(out_dir))
 	session.run(
-		'python', '-m', 'unittest', 'discover',
-		'-s', str(ROOT_DIR)
+		'python', *coverage_args, *unitest_args
 	)
+	if codecov and coverage:
+		session.run('codecov')
 
 @nox.session
-def docs(session: nox.Session) -> None:
+def docs(session: Session) -> None:
 	out_dir = (BUILD_DIR / 'docs')
 	shutil.rmtree(out_dir, ignore_errors = True)
 	session.install('-r', str(DOCS_DIR / 'requirements.txt'))
@@ -57,7 +77,7 @@ def docs(session: nox.Session) -> None:
 	session.run('sphinx-build', '-b', 'html', str(DOCS_DIR), str(out_dir))
 
 @nox.session
-def mypy(session: nox.Session) -> None:
+def typecheck(session: Session) -> None:
 	out_dir = (BUILD_DIR / 'mypy')
 	out_dir.mkdir(parents = True, exist_ok = True)
 
@@ -65,28 +85,37 @@ def mypy(session: nox.Session) -> None:
 	session.install('lxml')
 	session.install('.')
 	session.run(
-		'mypy', '--non-interactive', '--install-types',
+		'mypy', '--non-interactive', '--install-types', '--pretty',
+		'--cache-dir', str((out_dir / '.mypy-cache').resolve()),
+		'--config-file', str((CNTRB_DIR / '.mypy.ini').resolve()),
 		'-p', 'torii', '--html-report', str(out_dir.resolve())
 	)
 
 @nox.session
-def flake8(session: nox.Session) -> None:
+def lint(session: Session) -> None:
 	session.install('flake8')
-	session.run('flake8', './torii')
-	session.run('flake8', './examples')
-	session.run('flake8', './tests')
+	session.run(
+		'flake8', '--config', str((CNTRB_DIR / '.flake8').resolve()), './torii'
+	)
+	session.run(
+		'flake8', '--config', str((CNTRB_DIR / '.flake8').resolve()), './examples'
+	)
+	session.run(
+		'flake8', '--config', str((CNTRB_DIR / '.flake8').resolve()), './tests'
+	)
 
 @nox.session
-def build_dists(session: nox.Session) -> None:
+def dist(session: Session) -> None:
 	session.install('build')
-	session.run('python', '-m', 'build',
+	session.run(
+		'python', '-m', 'build',
 		'-o', str(DIST_DIR)
 	)
 
 @nox.session
-def upload_dist(session: nox.Session) -> None:
+def upload(session: Session) -> None:
 	session.install('twine')
-	build_dists(session)
+	dist(session)
 	session.log(f'Uploading torii-{torii_version()} to PyPi')
 	session.run(
 		'python', '-m', 'twine',
