@@ -1,19 +1,18 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 import io
+import re
 from collections  import OrderedDict
 from contextlib   import contextmanager
-from typing       import (
-	Union, Optional, Dict, Literal, Tuple
-)
+from typing       import Literal, Optional, Union
 
+from ..hdl        import ast, ir, mem, xfrm
 from ..util       import flatten
 from ..util.units import bits_for
-from ..hdl        import ast, ir, mem, xfrm
 
 __all__ = (
-	'convert',
 	'convert_fragment',
+	'convert',
 )
 
 _escape_map = str.maketrans({
@@ -105,7 +104,7 @@ class _AttrBuilder:
 	def _attribute(self, name: str, value: Union[str, int, ast.Const], *, indent: int = 0) -> None:
 		self._append('{}attribute \\{} {}\n', '  ' * indent, name, _const(value))
 
-	def _attributes(self, attrs: Dict[str, Union[str, int, ast.Const]], *, src: str = None, **kwargs) -> None:
+	def _attributes(self, attrs: dict[str, Union[str, int, ast.Const]], *, src: str = None, **kwargs) -> None:
 		for name, value in attrs.items():
 			self._attribute(name, value, **kwargs)
 		if src and self.emit_src:
@@ -116,12 +115,12 @@ class _Builder(_BufferedBuilder, _Namer):
 		super().__init__()
 		self.emit_src = emit_src
 
-	def module(self, name: str = None, attrs: Dict[str, Union[str, int, ast.Const]] = {}) -> '_ModuleBuilder':
+	def module(self, name: str = None, attrs: dict[str, Union[str, int, ast.Const]] = {}) -> '_ModuleBuilder':
 		name = self._make_name(name, local = False)
 		return _ModuleBuilder(self, name, attrs)
 
 class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
-	def __init__(self, rtlil, name: str, attrs: Dict[str, Union[str, int, ast.Const]]) -> None:
+	def __init__(self, rtlil, name: str, attrs: dict[str, Union[str, int, ast.Const]]) -> None:
 		super().__init__(emit_src = rtlil.emit_src)
 		self.rtlil = rtlil
 		self.name  = name
@@ -137,9 +136,10 @@ class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
 		self._append('end\n')
 		self.rtlil._buffer.write(str(self))
 
+	# FIXME: Type annotation for `port_id` seems to be incorrect
 	def wire(
 		self, width: int, port_id: Optional[str] = None, port_kind: Literal['input', 'output', 'inout'] = None,
-		name: str = None, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		name: str = None, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> str:
 		# Very large wires are unlikely to work. Verilog 1364-2005 requires the limit on vectors
 		# to be at least 2**16 bits, and Yosys 0.9 cannot read RTLIL with wires larger than 2**32
@@ -158,6 +158,15 @@ class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
 		else:
 			if port_kind not in ('input', 'output', 'inout'):
 				raise ValueError(f'Expected one of \'input\', \'output\', \'inout\' for port_kind, not {port_kind!r}')
+			# By convention, Yosys ports named $\d+ are positional, so there is no way to use
+			# a port with such a name. See amaranth-lang/amaranth#733.
+			if port_id is None:
+				# NOTE: This seems like it's not purely needed? as to get to this branch we ensure
+				# that `port_id` is not None anyway.
+				raise ValueError(
+					'Yosys ports named \'$\\d+\' are positional, and Torii does not support '
+					'connecting cell ports py position.'
+				)
 			self._append('  wire width {} {} {} {}\n', width, port_kind, port_id, name)
 		return name
 
@@ -165,7 +174,7 @@ class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
 		self._append('  connect {} {}\n', lhs, rhs)
 
 	def memory(
-		self, width: int, size: int, name: str = None, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		self, width: int, size: int, name: str = None, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> str:
 		self._attributes(attrs, src = src, indent = 1)
 		name = self._make_name(name, local = False)
@@ -173,8 +182,8 @@ class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
 		return name
 
 	def cell(
-		self, kind: str, name: str = None, params: Dict[str, Union[str, int, float, ast.Const]] = {},
-		ports: Dict[str, str] = {}, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		self, kind: str, name: str = None, params: dict[str, Union[str, int, float, ast.Const]] = {},
+		ports: dict[str, str] = {}, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> str:
 		self._attributes(attrs, src = src, indent = 1)
 		name = self._make_name(name, local = False)
@@ -187,18 +196,25 @@ class _ModuleBuilder(_AttrBuilder, _BufferedBuilder, _Namer):
 			else:
 				self._append('    parameter \\{} {}\n', param, _const(value))
 		for port, wire in ports.items():
+			# By convention, Yosys ports named $\d+ are positional. Torii does not support
+			# connecting cell ports by position. See amaranth-lang/amaranth#733.
+			if re.match(r'^\$\d+$', port):
+				raise ValueError(
+					f'Invalid port name \'{port}\'.\n Yosys ports named \'$\\d+\' are positional,'
+					'and Torii does not support connecting cell ports py position.'
+				)
 			self._append('    connect {} {}\n', port, wire)
 		self._append('  end\n')
 		return name
 
 	def process(
-		self, name: Optional[str] = None, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		self, name: Optional[str] = None, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> '_ProcessBuilder':
 		name = self._make_name(name, local = True)
 		return _ProcessBuilder(self, name, attrs, src)
 
 class _ProcessBuilder(_AttrBuilder, _BufferedBuilder):
-	def __init__(self, rtlil, name: str , attrs: Dict[str, Union[str, int, ast.Const]], src: str) -> None:
+	def __init__(self, rtlil, name: str , attrs: dict[str, Union[str, int, ast.Const]], src: str) -> None:
 		super().__init__(emit_src = rtlil.emit_src)
 		self.rtlil = rtlil
 		self.name  = name
@@ -236,14 +252,14 @@ class _CaseBuilder(_ProxiedBuilder):
 		self._append('{}assign {} {}\n', '  ' * self.indent, lhs, rhs)
 
 	def switch(
-		self, cond, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		self, cond, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> '_SwitchBuilder':
 		return _SwitchBuilder(self.rtlil, cond, attrs, src, self.indent)
 
 
 class _SwitchBuilder(_AttrBuilder, _ProxiedBuilder):
 	def __init__(
-		self, rtlil, cond, attrs: Dict[str, Union[str, int, ast.Const]] , src: str, indent: int
+		self, rtlil, cond, attrs: dict[str, Union[str, int, ast.Const]] , src: str, indent: int
 	) -> None:
 		super().__init__(emit_src = rtlil.emit_src)
 		self.rtlil  = rtlil
@@ -261,7 +277,7 @@ class _SwitchBuilder(_AttrBuilder, _ProxiedBuilder):
 		self._append('{}end\n', '  ' * self.indent)
 
 	def case(
-		self, *values, attrs: Dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
+		self, *values, attrs: dict[str, Union[str, int, ast.Const]] = {}, src: str = ''
 	) -> '_CaseBuilder':
 		self._attributes(attrs, src = src, indent = self.indent + 1)
 		if values == ():
@@ -293,7 +309,7 @@ class _SyncBuilder(_ProxiedBuilder):
 		self._append('      update {} {}\n', lhs, rhs)
 
 
-def _src(src_loc: Optional[Tuple[str, int]]) -> Optional[str]:
+def _src(src_loc: Optional[tuple[str, int]]) -> Optional[str]:
 	if src_loc is None:
 		return None
 	file, line = src_loc
@@ -301,7 +317,7 @@ def _src(src_loc: Optional[Tuple[str, int]]) -> Optional[str]:
 
 
 class _LegalizeValue(Exception):
-	def __init__(self, value, branches, src_loc: Optional[Tuple[str, int]]) -> None:
+	def __init__(self, value, branches, src_loc: Optional[tuple[str, int]]) -> None:
 		self.value    = value
 		self.branches = list(branches)
 		self.src_loc  = src_loc
@@ -423,10 +439,7 @@ class _ValueCompiler(xfrm.ValueVisitor):
 		if value.start == 0 and value.stop == len(value.value):
 			return self(value.value)
 
-		if isinstance(value.value, ast.UserValue):
-			sigspec = self._prepare_value_for_Slice(value.value._lazy_lower())
-		else:
-			sigspec = self._prepare_value_for_Slice(value.value)
+		sigspec = self._prepare_value_for_Slice(value.value)
 
 		if value.start == value.stop:
 			return '{}'
@@ -442,7 +455,7 @@ class _ValueCompiler(xfrm.ValueVisitor):
 				elem = value.elems[index.value]
 			else:
 				elem = value.elems[-1]
-			return self.match_shape(elem, *value.shape())
+			return self.match_shape(elem, value.shape())
 		else:
 			max_index = 1 << len(value.index)
 			max_elem  = len(value.elems)
@@ -487,12 +500,12 @@ class _RHSValueCompiler(_ValueCompiler):
 		if value in self.s.anys:
 			return self.s.anys[value]
 
-		res_bits, res_sign = value.shape()
-		res = self.s.rtlil.wire(width = res_bits, src = _src(value.src_loc))
+		res_shape = value.shape()
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell('$anyconst', ports = {
 			'\\Y': res,
 		}, params = {
-			'WIDTH': res_bits,
+			'WIDTH': res_shape.width,
 		}, src = _src(value.src_loc))
 		self.s.anys[value] = res
 		return res
@@ -501,12 +514,12 @@ class _RHSValueCompiler(_ValueCompiler):
 		if value in self.s.anys:
 			return self.s.anys[value]
 
-		res_bits, res_sign = value.shape()
-		res = self.s.rtlil.wire(width = res_bits, src = _src(value.src_loc))
+		res_shape = value.shape()
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell('$anyseq', ports = {
 			'\\Y': res,
 		}, params = {
-			'WIDTH': res_bits,
+			'WIDTH': res_shape.width,
 		}, src = _src(value.src_loc))
 		self.s.anys[value] = res
 		return res
@@ -521,74 +534,75 @@ class _RHSValueCompiler(_ValueCompiler):
 			# These operators don't change the bit pattern, only its interpretation.
 			return self(arg)
 
-		arg_bits, arg_sign = arg.shape()
-		res_bits, res_sign = value.shape()
-		res = self.s.rtlil.wire(width=res_bits, src=_src(value.src_loc))
+		arg_shape = arg.shape()
+		res_shape = value.shape()
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell(self.operator_map[(1, value.operator)], ports = {
 			'\\A': self(arg),
 			'\\Y': res,
 		}, params = {
-			'A_SIGNED': arg_sign,
-			'A_WIDTH' : arg_bits,
-			'Y_WIDTH' : res_bits,
+			'A_SIGNED': arg_shape.signed,
+			'A_WIDTH' : arg_shape.width,
+			'Y_WIDTH' : res_shape.width,
 		}, src = _src(value.src_loc))
 		return res
 
-	def match_shape(self, value, new_bits, new_sign):
+	def match_shape(self, value, new_shape):
 		if isinstance(value, ast.Const):
-			return self(ast.Const(value.value, ast.Shape(new_bits, new_sign)))
+			return self(ast.Const(value.value, new_shape))
 
-		value_bits, value_sign = value.shape()
-		if new_bits <= value_bits:
-			return self(ast.Slice(value, 0, new_bits))
+		value_shape = value.shape()
+		if new_shape.width <= value_shape.width:
+			return self(ast.Slice(value, 0, new_shape.width))
 
-		res = self.s.rtlil.wire(width = new_bits, src = _src(value.src_loc))
+		res = self.s.rtlil.wire(width = new_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell('$pos', ports = {
 			'\\A': self(value),
 			'\\Y': res,
 		}, params = {
-			'A_SIGNED': value_sign,
-			'A_WIDTH' : value_bits,
-			'Y_WIDTH' : new_bits,
+			'A_SIGNED': value_shape.signed,
+			'A_WIDTH' : value_shape.width,
+			'Y_WIDTH' : new_shape.width,
 		}, src = _src(value.src_loc))
 		return res
 
 	def on_Operator_binary(self, value):
 		lhs, rhs = value.operands
-		lhs_bits, lhs_sign = lhs.shape()
-		rhs_bits, rhs_sign = rhs.shape()
-		if lhs_sign == rhs_sign or value.operator in ('<<', '>>', '**'):
+		lhs_shape = lhs.shape()
+		rhs_shape = rhs.shape()
+		res_shape = value.shape()
+
+		if lhs_shape.signed == rhs_shape.signed or value.operator in ('<<', '>>', '**'):
 			lhs_wire = self(lhs)
 			rhs_wire = self(rhs)
 		else:
-			lhs_bits = rhs_bits = max(lhs_bits + rhs_sign, rhs_bits + lhs_sign)
-			lhs_sign = rhs_sign = True
-			lhs_wire = self.match_shape(lhs, lhs_bits, lhs_sign)
-			rhs_wire = self.match_shape(rhs, rhs_bits, rhs_sign)
-		res_bits, res_sign = value.shape()
-		res = self.s.rtlil.wire(width = res_bits, src = _src(value.src_loc))
+			lhs_shape = rhs_shape = ast.signed(max(lhs_shape.width + rhs_shape.signed, rhs_shape.width + lhs_shape.signed))
+
+			lhs_wire = self.match_shape(lhs, lhs_shape)
+			rhs_wire = self.match_shape(rhs, rhs_shape)
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell(self.operator_map[(2, value.operator)], ports = {
 			'\\A': lhs_wire,
 			'\\B': rhs_wire,
 			'\\Y': res,
 		}, params = {
-			'A_SIGNED': lhs_sign,
-			'A_WIDTH' : lhs_bits,
-			'B_SIGNED': rhs_sign,
-			'B_WIDTH' : rhs_bits,
-			'Y_WIDTH' : res_bits,
+			'A_SIGNED': lhs_shape.signed,
+			'A_WIDTH' : lhs_shape.width,
+			'B_SIGNED': rhs_shape.signed,
+			'B_WIDTH' : rhs_shape.width,
+			'Y_WIDTH' : res_shape.width,
 		}, src = _src(value.src_loc))
 		if value.operator in ('//', '%'):
 			# RTLIL leaves division by zero undefined, but we require it to return zero.
 			divmod_res = res
-			res = self.s.rtlil.wire(width = res_bits, src = _src(value.src_loc))
+			res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 			self.s.rtlil.cell('$mux', ports = {
 				'\\A': divmod_res,
-				'\\B': self(ast.Const(0, ast.Shape(res_bits, res_sign))),
+				'\\B': self(ast.Const(0, res_shape)),
 				'\\S': self(rhs == 0),
 				'\\Y': res,
 			}, params = {
-				'WIDTH': res_bits
+				'WIDTH': res_shape.width
 			}, src = _src(value.src_loc))
 		return res
 
@@ -596,20 +610,17 @@ class _RHSValueCompiler(_ValueCompiler):
 		sel, val1, val0 = value.operands
 		if len(sel) != 1:
 			sel = sel.bool()
-		val1_bits, val1_sign = val1.shape()
-		val0_bits, val0_sign = val0.shape()
-		res_bits, res_sign = value.shape()
-		val1_bits = val0_bits = res_bits = max(val1_bits, val0_bits, res_bits)
-		val1_wire = self.match_shape(val1, val1_bits, val1_sign)
-		val0_wire = self.match_shape(val0, val0_bits, val0_sign)
-		res = self.s.rtlil.wire(width = res_bits, src = _src(value.src_loc))
+		res_shape = value.shape()
+		val1_wire = self.match_shape(val1, res_shape)
+		val0_wire = self.match_shape(val0, res_shape)
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		self.s.rtlil.cell('$mux', ports = {
 			'\\A': val0_wire,
 			'\\B': val1_wire,
 			'\\S': self(sel),
 			'\\Y': res,
 		}, params = {
-			'WIDTH': res_bits
+			'WIDTH': res_shape.width
 		}, src = _src(value.src_loc))
 		return res
 
@@ -636,10 +647,10 @@ class _RHSValueCompiler(_ValueCompiler):
 		lhs, rhs = value.value, value.offset
 		if value.stride != 1:
 			rhs *= value.stride
-		lhs_bits, lhs_sign = lhs.shape()
-		rhs_bits, rhs_sign = rhs.shape()
-		res_bits, res_sign = value.shape()
-		res = self.s.rtlil.wire(width=res_bits, src = _src(value.src_loc))
+		lhs_shape = lhs.shape()
+		rhs_shape = rhs.shape()
+		res_shape = value.shape()
+		res = self.s.rtlil.wire(width = res_shape.width, src = _src(value.src_loc))
 		# Note: Verilog's x[o+:w] construct produces a $shiftx cell, not a $shift cell.
 		# However, Torii's semantics defines the out-of-range bits to be zero, so it is correct
 		# to use a $shift cell here instead, even though it produces less idiomatic Verilog.
@@ -648,11 +659,11 @@ class _RHSValueCompiler(_ValueCompiler):
 			'\\B': self(rhs),
 			'\\Y': res,
 		}, params = {
-			'A_SIGNED': lhs_sign,
-			'A_WIDTH' : lhs_bits,
-			'B_SIGNED': rhs_sign,
-			'B_WIDTH' : rhs_bits,
-			'Y_WIDTH' : res_bits,
+			'A_SIGNED': lhs_shape.signed,
+			'A_WIDTH' : lhs_shape.width,
+			'B_SIGNED': rhs_shape.signed,
+			'B_WIDTH' : rhs_shape.width,
+			'Y_WIDTH' : res_shape.width,
 		}, src = _src(value.src_loc))
 		return res
 
@@ -678,14 +689,14 @@ class _LHSValueCompiler(_ValueCompiler):
 
 		raise TypeError # :nocov:
 
-	def match_shape(self, value, new_bits, new_sign):
-		value_bits, value_sign = value.shape()
-		if new_bits == value_bits:
+	def match_shape(self, value, new_shape):
+		value_shape = value.shape()
+		if new_shape.width == value_shape.width:
 			return self(value)
-		elif new_bits < value_bits:
-			return self(ast.Slice(value, 0, new_bits))
-		else: # new_bits > value_bits
-			dummy_bits = new_bits - value_bits
+		elif new_shape.width < value_shape.width:
+			return self(ast.Slice(value, 0, new_shape.width))
+		else: # new_shape.width > value_shape.width
+			dummy_bits = new_shape.width - value_shape.width
 			dummy_wire = self.s.rtlil.wire(dummy_bits)
 			return f'{{ {dummy_wire} {self(value)} }}'
 
@@ -737,7 +748,7 @@ class _StatementCompiler(xfrm.StatementVisitor):
 		self._wrap_assign = False
 
 	@contextmanager
-	def case(self, switch, values, attrs={}, src = ''):
+	def case(self, switch, values, attrs = {}, src = ''):
 		try:
 			old_case = self._case
 			with switch.case(*values, attrs = attrs, src = src) as self._case:
@@ -752,14 +763,13 @@ class _StatementCompiler(xfrm.StatementVisitor):
 	def on_Assign(self, stmt):
 		self._check_rhs(stmt.rhs)
 
-		lhs_bits, lhs_sign = stmt.lhs.shape()
-		rhs_bits, rhs_sign = stmt.rhs.shape()
-		if lhs_bits == rhs_bits:
+		lhs_shape = stmt.lhs.shape()
+		rhs_shape = stmt.rhs.shape()
+		if lhs_shape.width == rhs_shape.width:
 			rhs_sigspec = self.rhs_compiler(stmt.rhs)
 		else:
 			# In RTLIL, LHS and RHS of assignment must have exactly same width.
-			rhs_sigspec = self.rhs_compiler.match_shape(
-				stmt.rhs, lhs_bits, lhs_sign)
+			rhs_sigspec = self.rhs_compiler.match_shape(stmt.rhs, lhs_shape)
 		if self._wrap_assign:
 			# In RTLIL, all assigns are logically sequenced before all switches, even if they are
 			# interleaved in the source. In Torii, the source ordering is used. To handle this
@@ -779,7 +789,7 @@ class _StatementCompiler(xfrm.StatementVisitor):
 		self.state.rtlil.cell('$' + stmt._kind, ports = {
 			'\\A' : check_wire,
 			'\\EN': en_wire,
-		}, src = _src(stmt.src_loc))
+		}, src = _src(stmt.src_loc), name = stmt.name)
 
 	on_Assert = on_property
 	on_Assume = on_property
@@ -803,8 +813,9 @@ class _StatementCompiler(xfrm.StatementVisitor):
 		with self._case.switch(test_sigspec, src = _src(stmt.src_loc)) as switch:
 			for values, stmts in stmt.cases.items():
 				case_attrs = {}
+				case_src = None
 				if values in stmt.case_src_locs:
-					case_attrs['src'] = _src(stmt.case_src_locs[values])
+					case_src = _src(stmt.case_src_locs[values])
 				if isinstance(stmt.test, ast.Signal) and stmt.test.decoder:
 					decoded_values = []
 					for value in values:
@@ -813,7 +824,7 @@ class _StatementCompiler(xfrm.StatementVisitor):
 						else:
 							decoded_values.append(stmt.test.decoder(int(value, 2)))
 					case_attrs['torii.decoding'] = '|'.join(decoded_values)
-				with self.case(switch, values, attrs = case_attrs):
+				with self.case(switch, values, attrs = case_attrs, src = case_src):
 					self._wrap_assign = False
 					self.on_statements(stmts)
 		self._wrap_assign = True
@@ -874,7 +885,7 @@ def _convert_fragment(builder, fragment, name_map, hierarchy):
 		# Register all signals driven in the current fragment. This must be done first, as it
 		# affects further codegen; e.g. whether \sig$next signals will be generated and used.
 		for domain, signal in fragment.iter_drivers():
-			compiler_state.add_driven(signal, sync=domain is not None)
+			compiler_state.add_driven(signal, sync = domain is not None)
 
 		# Transform all signals used as ports in the current fragment eagerly and outside of
 		# any hierarchy, to make sure they get sensible (non-prefixed) names.
@@ -942,7 +953,7 @@ def _convert_fragment(builder, fragment, name_map, hierarchy):
 			for port, value in sub_port_map.items():
 				if not isinstance(subfragment, ir.Instance):
 					for signal in value._rhs_signals():
-						compiler_state.resolve_curr(signal, prefix=sub_name)
+						compiler_state.resolve_curr(signal, prefix = sub_name)
 				if len(value) > 0:
 					sub_ports[port] = rhs_compiler(value)
 
@@ -1025,7 +1036,7 @@ def _convert_fragment(builder, fragment, name_map, hierarchy):
 		#
 		# Because this assignment is done at a late stage, a single Signal object can get assigned
 		# many times, once in each module it is used. This is a deliberate decision; the possible
-		# alternatives are to add ports for undriven signals (which requires choosing one module
+		# alternatives are to add ports for un-driven signals (which requires choosing one module
 		# to drive it to reset value arbitrarily) or to replace them with their reset value (which
 		# removes valuable source location information).
 		driven = ast.SignalSet()
@@ -1063,7 +1074,7 @@ def _convert_fragment(builder, fragment, name_map, hierarchy):
 
 def convert_fragment(
 	fragment: ir.Fragment, name: str = 'top', *, emit_src: str = True
-) -> Tuple[str, ast.SignalDict]:
+) -> tuple[str, ast.SignalDict]:
 	if not isinstance(fragment, ir.Fragment):
 		raise ValueError(f'Expected an ir.Fragment not a {fragment!r}')
 	builder = _Builder(emit_src = emit_src)
@@ -1073,7 +1084,7 @@ def convert_fragment(
 
 
 def convert(
-	elaboratable, name: str = 'top', platform = None, ports = None, *, emit_src = True, **kwargs
+	elaboratable, name: str = 'top', platform = None, *, ports,  emit_src = True, **kwargs
 ) -> str:
 	fragment = ir.Fragment.get(elaboratable, platform).prepare(ports = ports, **kwargs)
 	il_text, _ = convert_fragment(fragment, name, emit_src = emit_src)
