@@ -1,27 +1,31 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from typing             import Tuple, Union
+from typing        import Union
 
-from .._toolchain.yosys import find_yosys, YosysError
-from ..hdl              import ir, ast
-from .                  import rtlil
+from ..hdl         import ast, ir
+from ..tools.yosys import YosysError, find_yosys
+from .             import rtlil
 
 __all__ = (
-	'YosysError',
-	'convert',
 	'convert_fragment',
+	'convert',
+	'YosysError',
 )
 
 
 def _convert_rtlil_text(
-	rtlil_text: str, *, strip_internal_attrs: bool = False, write_verilog_opts: Tuple[str] = ()
+	rtlil_text: str, *, strip_internal_attrs: bool = False, write_verilog_opts: tuple[str] = ()
 ) -> str:
-	# this version requirement needs to be synchronized with the one in setup.py!
-	yosys = find_yosys(lambda ver: ver >= (0, 10))
+
+	yosys = find_yosys()
+	yosys_version = yosys.version()
 
 	script = []
-	script.append(f'read_ilang <<rtlil\n{rtlil_text}\nrtlil')
-	script.append('proc -nomux')
+	script.append(f'read_rtlil <<rtlil\n{rtlil_text}\nrtlil')
+	if yosys_version >= (0, 17):
+		script.append('proc -nomux -norom')
+	else:
+		script.append('proc -nomux')
 	script.append('memory_collect')
 
 	if strip_internal_attrs:
@@ -44,14 +48,14 @@ def _convert_rtlil_text(
 	)
 
 
-def convert_fragment(*args, strip_internal_attrs: bool = False, **kwargs) -> Tuple[str, ast.SignalDict]:
+def convert_fragment(*args, strip_internal_attrs: bool = False, **kwargs) -> tuple[str, ast.SignalDict]:
 	rtlil_text, name_map = rtlil.convert_fragment(*args, **kwargs)
-	return (_convert_rtlil_text(rtlil_text, strip_internal_attrs=strip_internal_attrs), name_map)
+	return (_convert_rtlil_text(rtlil_text, strip_internal_attrs = strip_internal_attrs), name_map)
 
 
 def convert(
-	elaboratable: Union[ir.Fragment, ir.Elaboratable], name: str = 'top', platform = None, ports = None,
-	*, emit_src: bool = True, strip_internal_attrs: bool = False, **kwargs
+	elaboratable: Union[ir.Fragment, ir.Elaboratable], name: str = 'top', platform = None, *, ports,
+	emit_src: bool = True, strip_internal_attrs: bool = False, **kwargs
 ) -> str:
 
 	fragment = ir.Fragment.get(elaboratable, platform).prepare(ports = ports, **kwargs)
