@@ -1,24 +1,31 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-import logging    as log
-from argparse     import ArgumentParser, FileType, Namespace
-from typing       import Optional, Tuple, Union
+import logging        as log
+from argparse         import (
+	ArgumentDefaultsHelpFormatter, ArgumentParser, FileType, Namespace
+)
+from typing           import Optional, Union
 
-from rich         import traceback
-from rich.logging import RichHandler
+from rich             import traceback
+from rich.logging     import RichHandler
 
-from .back        import cxxrtl, rtlil, verilog
-from .build       import Platform
-from .hdl.ir      import Elaboratable, Fragment, Signal
-from .sim         import Simulator
+from .back            import cxxrtl, rtlil, verilog
+from .build           import Platform
+from .hdl.ir          import Elaboratable, Fragment, Signal
+from .sim             import Simulator
+from .util.decorators import deprecated
 
 __all__ = (
 	'main',
 )
 
+@deprecated('torii.cli.main_parser will be replaced in a future version of Torii')
 def main_parser(parser: Optional[ArgumentParser] = None) -> ArgumentParser:
 	if parser is None:
-		parser = ArgumentParser()
+		parser = ArgumentParser(
+			formatter_class = ArgumentDefaultsHelpFormatter,
+			description     = 'Torii-HDL CLI Runner'
+		)
 
 	parser.add_argument(
 		'-v', '--verbose',
@@ -92,9 +99,10 @@ def main_parser(parser: Optional[ArgumentParser] = None) -> ArgumentParser:
 	return parser
 
 
+@deprecated('torii.cli.main_runner will be replaced in a future version of Torii')
 def main_runner(
 	parser: ArgumentParser, args: Namespace, design: Union[Fragment, Elaboratable],
-	platform: Platform = None, name: str = 'top', ports: Tuple[Signal] = ()
+	platform: Platform = None, name: str = 'top', ports: tuple[Signal] = ()
 ) -> None:
 
 	level = log.INFO
@@ -142,7 +150,7 @@ def main_runner(
 		with sim.write_vcd(vcd_file = args.vcd_file, gtkw_file = args.gtkw_file, traces = ports):
 			sim.run_until(args.sync_period * args.sync_clocks, run_passive = True)
 
-
+@deprecated('torii.cli.main will be replaced in a future version of Torii')
 def main(*args, **kwargs) -> None:
 	traceback.install()
 	parser = main_parser()
