@@ -12,13 +12,26 @@ from .rec  import Record
 from .xfrm import DomainRenamer, EnableInserter, ResetInserter
 
 __all__ = (
-	'Shape', 'unsigned', 'signed', 'Value', 'Const',
-	'Mux', 'Cat', 'Repl', 'Array',
-	'Signal', 'ClockSignal', 'ResetSignal',
-	'Module',
+	'Array',
+	'Cat',
 	'ClockDomain',
-	'Elaboratable', 'Fragment', 'Instance',
+	'ClockSignal',
+	'Const',
+	'DomainRenamer',
+	'Elaboratable',
+	'EnableInserter',
+	'Fragment',
+	'Instance',
 	'Memory',
+	'Module',
+	'Mux',
 	'Record',
-	'DomainRenamer', 'ResetInserter', 'EnableInserter',
+	'Repl',
+	'ResetInserter',
+	'ResetSignal',
+	'Shape',
+	'Signal',
+	'signed',
+	'unsigned',
+	'Value',
 )
