@@ -9,28 +9,58 @@ from collections.abc   import (
 )
 from enum              import Enum
 from itertools         import chain
-from typing            import Iterator, Optional, Tuple, Union
+from typing            import Optional, Union
 
-from ._unused          import MustUse, UnusedMustUse
-from ..util            import tracer, flatten, union
-from ..util.decorators import final, deprecated
+from ..util            import flatten, tracer, union
+from ..util.decorators import final
 from ..util.units      import bits_for
+from ._unused          import MustUse, UnusedMustUse
 
 __all__ = (
-	'Shape', 'signed', 'unsigned', 'ShapeCastable',
-	'Value', 'Const', 'AnyConst', 'AnySeq', 'Operator', 'Mux', 'Part', 'Slice', 'Cat', 'Repl',
-	'Array', 'ArrayProxy',
-	'Signal', 'ClockSignal', 'ResetSignal',
-	'UserValue', 'ValueCastable',
-	'Sample', 'Past', 'Stable', 'Rose', 'Fell', 'Initial',
-	'Statement', 'Switch',
-	'Property', 'Assign', 'Assert', 'Assume', 'Cover',
-	'ValueKey', 'ValueDict', 'ValueSet', 'SignalKey', 'SignalDict', 'SignalSet',
+	'AnyConst',
+	'AnySeq',
+	'Array',
+	'ArrayProxy',
+	'Assert',
+	'Assign',
+	'Assume',
+	'Cat',
+	'ClockSignal',
+	'Const',
+	'Cover',
+	'Fell',
+	'Initial',
+	'Mux',
+	'Operator',
+	'Part',
+	'Past',
+	'Property',
+	'Repl',
+	'ResetSignal',
+	'Rose',
+	'Sample',
+	'Shape',
+	'ShapeCastable',
+	'Signal',
+	'SignalDict',
+	'SignalKey',
+	'SignalSet',
+	'signed',
+	'Slice',
+	'Stable',
+	'Statement',
+	'Switch',
+	'unsigned',
+	'Value',
+	'ValueCastable',
+	'ValueDict',
+	'ValueKey',
+	'ValueSet',
 )
 
 
 class DUID:
-	'''Deterministic Unique IDentifier.'''
+	''' Deterministic Unique IDentifier. '''
 	__next_uid = 0
 
 	def __init__(self) -> None:
@@ -39,22 +69,25 @@ class DUID:
 
 
 class ShapeCastable:
-	'''Interface of user-defined objects that can be cast to :class:`Shape` s.
+	'''
+	Interface of user-defined objects that can be cast to :class:`Shape`s.
 
 	An object deriving from :class:`ShapeCastable` is automatically converted to a :class:`Shape`
 	when it is used in a context where a :class:`Shape` is expected. Such objects can contain
 	a richer description of the shape than what is supported by the core Torii language, yet
 	still be transparently used with it.
+
 	'''
-	def __new__(cls, *args, **kwargs) -> 'ShapeCastable':
-		self = super().__new__(cls)
-		if not hasattr(self, 'as_shape'):
+
+	def __init_subclass__(cls, **kwargs):
+		if not hasattr(cls, 'as_shape'):
 			raise TypeError(f'Class \'{cls.__name__}\' deriving from `ShapeCastable` must override the `as_shape` method')
-		return self
+
 
 
 class Shape:
-	'''Bit width and signedness of a value.
+	'''
+	Bit width and signedness of a value.
 
 	A ``Shape`` can be constructed using:
 
@@ -77,7 +110,9 @@ class Shape:
 		The number of bits in the representation, including the sign bit (if any).
 	signed : bool
 		If ``False``, the value is unsigned. If ``True``, the value is signed two's complement.
+
 	'''  # noqa: E101
+
 	def __init__(self, width: int = 1, signed: bool = False) -> None:
 		if not isinstance(width, int) or width < 0:
 			raise TypeError(f'Width must be a non-negative integer, not {width!r}')
@@ -85,9 +120,28 @@ class Shape:
 		self.width = width
 		self.signed = signed
 
-	# TODO(nmigen-0.4): remove
-	def __iter__(self) -> Iterator[Tuple[int, bool]]:
-		return iter((self.width, self.signed))
+	# This implements an algorithm for inferring shape from standard Python enumerations
+	# for `Shape.cast()`.
+	@staticmethod
+	def _cast_plain_enum(obj):
+		signed = False
+		width  = 0
+		for member in obj:
+			try:
+				member_shape = Const.cast(member.value).shape()
+			except TypeError:
+				raise TypeError(
+					'Only enumerations whose members have constant-castable '
+					'values can be used in Torii code'
+				)
+			if not signed and member_shape.signed:
+				signed = True
+				width  = max(width + 1, member_shape.width)
+			elif signed and not member_shape.signed:
+				width  = max(width, member_shape.width + 1)
+			else:
+				width  = max(width, member_shape.width)
+		return Shape(width, signed)
 
 	@staticmethod
 	def cast(
@@ -97,6 +151,8 @@ class Shape:
 		while True:
 			if isinstance(obj, Shape):
 				return obj
+			elif isinstance(obj, ShapeCastable):
+				new_obj = obj.as_shape()
 			elif isinstance(obj, int):
 				return Shape(obj)
 			elif isinstance(obj, range):
@@ -109,15 +165,7 @@ class Shape:
 				)
 				return Shape(width, signed)
 			elif isinstance(obj, type) and issubclass(obj, Enum):
-				min_value = min(member.value for member in obj)
-				max_value = max(member.value for member in obj)
-				if not isinstance(min_value, int) or not isinstance(max_value, int):
-					raise TypeError('Only enumerations with integer values can be used as value shapes')
-				signed = min_value < 0 or max_value < 0
-				width  = max(bits_for(min_value, signed), bits_for(max_value, signed))
-				return Shape(width, signed)
-			elif isinstance(obj, ShapeCastable):
-				new_obj = obj.as_shape()
+				return Shape._cast_plain_enum(obj)
 			else:
 				raise TypeError(f'Object {obj!r} cannot be converted to a Torii shape')
 			if new_obj is obj:
@@ -130,14 +178,7 @@ class Shape:
 		else:
 			return f'unsigned({self.width})'
 
-	def __eq__(self, other: Union[Tuple[int, bool], 'Shape']) -> bool:
-		# TODO(nmigen-0.4): remove
-		if isinstance(other, tuple) and len(other) == 2:
-			width, signed = other
-			if isinstance(width, int) and isinstance(signed, bool):
-				return self.width == width and self.signed == signed
-			else:
-				raise TypeError(f'Shapes may be compared with other Shapes and (int, bool) tuples, not {other!r}')
+	def __eq__(self, other: Union[tuple[int, bool], 'Shape']) -> bool:
 		if not isinstance(other, Shape):
 			try:
 				other = self.__class__.cast(other)
@@ -147,12 +188,12 @@ class Shape:
 
 
 def unsigned(width: int) -> Shape:
-	'''Shorthand for ``Shape(width, signed=False)``.'''
+	''' Shorthand for ``Shape(width, signed = False)``. '''
 	return Shape(width, signed = False)
 
 
 def signed(width: int) -> Shape:
-	'''Shorthand for ``Shape(width, signed=True)``.'''
+	''' Shorthand for ``Shape(width, signed = True)``. '''
 	return Shape(width, signed = True)
 
 
@@ -161,21 +202,24 @@ ValueCastType = Union['Value', int, Enum, 'ValueCastable']
 class Value(metaclass = ABCMeta):
 	@staticmethod
 	def cast(obj: ValueCastType ) -> 'Value':
-		'''Converts ``obj`` to an Torii value.
+		'''
+		Converts ``obj`` to an Torii value.
 
 		Booleans and integers are wrapped into a :class:`Const`. Enumerations whose members are
 		all integers are converted to a :class:`Const` with a shape that fits every member.
 		:class:`ValueCastable` objects are recursively cast to an Torii value.
+
 		'''
+
 		while True:
 			if isinstance(obj, Value):
 				return obj
-			elif isinstance(obj, int):
-				return Const(obj)
-			elif isinstance(obj, Enum):
-				return Const(obj.value, Shape.cast(type(obj)))
 			elif isinstance(obj, ValueCastable):
 				new_obj = obj.as_value()
+			elif isinstance(obj, Enum):
+				return Const(obj.value, Shape.cast(type(obj)))
+			elif isinstance(obj, int):
+				return Const(obj)
 			else:
 				raise TypeError(f'Object {obj!r} cannot be converted to a Torii value')
 			if new_obj is obj:
@@ -189,6 +233,9 @@ class Value(metaclass = ABCMeta):
 	def __bool__(self) -> None:
 		raise TypeError('Attempted to convert Torii value to Python boolean')
 
+	def __pos__(self) -> 'Value':
+		return self
+
 	def __invert__(self) -> 'Operator':
 		return Operator('~', [self])
 
@@ -228,8 +275,7 @@ class Value(metaclass = ABCMeta):
 
 
 	def __check_shamt(self) -> None:
-		width, signed = self.shape()
-		if signed:
+		if self.shape().signed:
 			# Neither Python nor HDLs implement shifts by negative values; prohibit any shifts
 			# by a signed value to make sure the shift amount can always be interpreted as
 			# an unsigned value.
@@ -290,8 +336,7 @@ class Value(metaclass = ABCMeta):
 		return Operator('>=', [self, other])
 
 	def __abs__(self) -> 'Value':
-		width, signed = self.shape()
-		if signed:
+		if self.shape().signed:
 			return Mux(self >= 0, self, -self)
 		else:
 			return self
@@ -316,77 +361,99 @@ class Value(metaclass = ABCMeta):
 			raise TypeError(f'Cannot index value with {key!r}')
 
 	def as_unsigned(self)  -> 'Operator':
-		'''Conversion to unsigned.
+		'''
+		Conversion to unsigned.
 
 		Returns
 		-------
 		Value, out
 			This ``Value`` reinterpreted as a unsigned integer.
+
 		'''
+
 		return Operator('u', [self])
 
 	def as_signed(self)  -> 'Operator':
-		'''Conversion to signed.
+		'''
+		Conversion to signed.
 
 		Returns
 		-------
 		Value, out
 			This ``Value`` reinterpreted as a signed integer.
+
 		'''
+
 		return Operator('s', [self])
 
 	def bool(self)  -> 'Operator':
-		'''Conversion to boolean.
+		'''
+		Conversion to boolean.
 
 		Returns
 		-------
 		Value, out
 			``1`` if any bits are set, ``0`` otherwise.
+
 		'''
+
 		return Operator('b', [self])
 
 	def any(self)  -> 'Operator':
-		'''Check if any bits are ``1``.
+		'''
+		Check if any bits are ``1``.
 
 		Returns
 		-------
 		Value, out
 			``1`` if any bits are set, ``0`` otherwise.
+
 		'''
+
 		return Operator('r|', [self])
 
 	def all(self)  -> 'Operator':
-		'''Check if all bits are ``1``.
+		'''
+		Check if all bits are ``1``.
 
 		Returns
 		-------
 		Value, out
 			``1`` if all bits are set, ``0`` otherwise.
+
 		'''
+
 		return Operator('r&', [self])
 
 	def xor(self)  -> 'Operator':
-		'''Compute pairwise exclusive-or of every bit.
+		'''
+		Compute pairwise exclusive-or of every bit.
 
 		Returns
 		-------
 		Value, out
 			``1`` if an odd number of bits are set, ``0`` if an even number of bits are set.
+
 		'''
+
 		return Operator('r^', [self])
 
 	def implies(premise, conclusion: ValueCastType)  -> 'Operator':
-		'''Implication.
+		'''
+		Implication.
 
 		Returns
 		-------
 		Value, out
 			``0`` if ``premise`` is true and ``conclusion`` is not, ``1`` otherwise.
+
 		'''
+
 		return ~premise | conclusion
 
 	def bit_select(self, offset: Union['Value', int] , width: int) -> 'Part':
-		'''Part-select with bit granularity.
+		'''
+		Part-select with bit granularity.
 
 		Selects a constant width but variable offset part of a ``Value``, such that successive
 		parts overlap by all but 1 bit.
@@ -402,14 +469,17 @@ class Value(metaclass = ABCMeta):
 		-------
 		Part, out
 			Selected part of the ``Value``
+
 		'''
+
 		offset = Value.cast(offset)
 		if type(offset) is Const and isinstance(width, int):
 			return self[offset.value:offset.value + width]
 		return Part(self, offset, width, stride = 1, src_loc_at = 1)
 
 	def word_select(self, offset: Union['Value', int] , width: int) -> 'Part':
-		'''Part-select with word granularity.
+		'''
+		Part-select with word granularity.
 
 		Selects a constant width but variable offset part of a ``Value``, such that successive
 		parts do not overlap.
@@ -425,14 +495,17 @@ class Value(metaclass = ABCMeta):
 		-------
 		Part, out
 			Selected part of the ``Value``
+
 		'''
+
 		offset = Value.cast(offset)
 		if type(offset) is Const and isinstance(width, int):
 			return self[offset.value * width:(offset.value + 1) * width]
 		return Part(self, offset, width, stride = width, src_loc_at = 1)
 
-	def matches(self, *patterns: Tuple[Union[int, str, Enum]]) -> 'Value':
-		'''Pattern matching.
+	def matches(self, *patterns: tuple[Union[int, str, Enum]]) -> 'Value':
+		'''
+		Pattern matching.
 
 		Matches against a set of patterns, which may be integers or bit strings, recognizing
 		the same grammar as ``Case()``.
@@ -446,7 +519,9 @@ class Value(metaclass = ABCMeta):
 		-------
 		Value, out
 			``1`` if any pattern matches the value, ``0`` otherwise.
+
 		'''
+
 		matches = []
 		for pattern in patterns:
 			if not isinstance(pattern, (int, str, Enum)):
@@ -466,7 +541,8 @@ class Value(metaclass = ABCMeta):
 
 			if isinstance(pattern, int) and bits_for(pattern) > len(self):
 				warnings.warn(
-					f'Match pattern \'{pattern:b}\' is wider than match value (which has width {len(self)}); comparison will never be true',
+					f'Match pattern \'{pattern:b}\' is wider than match value (which has width {len(self)}); '
+					'comparison will never be true',
 					SyntaxWarning, stacklevel = 3
 				)
 				continue
@@ -482,14 +558,15 @@ class Value(metaclass = ABCMeta):
 			else:
 				assert False
 		if not matches:
-			return Const(0)
+			return Const(1)
 		elif len(matches) == 1:
 			return matches[0]
 		else:
 			return Cat(*matches).any()
 
 	def shift_left(self, amount: int) -> 'Value':
-		'''Shift left by constant amount.
+		'''
+		Shift left by constant amount.
 
 		Parameters
 		----------
@@ -500,7 +577,9 @@ class Value(metaclass = ABCMeta):
 		-------
 		Value, out
 			If the amount is positive, the input shifted left. Otherwise, the input shifted right.
+
 		'''
+
 		if not isinstance(amount, int):
 			raise TypeError(f'Shift amount must be an integer, not {amount!r}')
 		if amount < 0:
@@ -511,7 +590,8 @@ class Value(metaclass = ABCMeta):
 			return Cat(Const(0, amount), self) # unsigned
 
 	def shift_right(self, amount: int) -> 'Value':
-		'''Shift right by constant amount.
+		'''
+		Shift right by constant amount.
 
 		Parameters
 		----------
@@ -522,7 +602,9 @@ class Value(metaclass = ABCMeta):
 		-------
 		Value, out
 			If the amount is positive, the input shifted right. Otherwise, the input shifted left.
+
 		'''
+
 		if not isinstance(amount, int):
 			raise TypeError(f'Shift amount must be an integer, not {amount!r}')
 		if amount < 0:
@@ -533,7 +615,8 @@ class Value(metaclass = ABCMeta):
 			return self[amount:] # unsigned
 
 	def rotate_left(self, amount: int) -> 'Value':
-		'''Rotate left by constant amount.
+		'''
+		Rotate left by constant amount.
 
 		Parameters
 		----------
@@ -544,14 +627,17 @@ class Value(metaclass = ABCMeta):
 		-------
 		Value, out
 			If the amount is positive, the input rotated left. Otherwise, the input rotated right.
+
 		'''
+
 		if not isinstance(amount, int):
 			raise TypeError(f'Rotate amount must be an integer, not {amount!r}')
 		amount %= len(self)
 		return Cat(self[-amount:], self[:-amount]) # meow :3
 
 	def rotate_right(self, amount: int) -> 'Value':
-		'''Rotate right by constant amount.
+		'''
+		Rotate right by constant amount.
 
 		Parameters
 		----------
@@ -562,14 +648,17 @@ class Value(metaclass = ABCMeta):
 		-------
 		Value, out
 			If the amount is positive, the input rotated right. Otherwise, the input rotated right.
+
 		'''
+
 		if not isinstance(amount, int):
 			raise TypeError(f'Rotate amount must be an integer, not {amount!r}')
 		amount %= len(self)
 		return Cat(self[amount:], self[:amount])
 
 	def eq(self, value: 'Value') -> 'Assign':
-		'''Assignment.
+		'''
+		Assignment.
 
 		Parameters
 		----------
@@ -580,12 +669,15 @@ class Value(metaclass = ABCMeta):
 		-------
 		Assign
 			Assignment statement that can be used in combinatorial or synchronous context.
+
 		'''
+
 		return Assign(self, value, src_loc_at = 1)
 
 	@abstractmethod
 	def shape(self) -> Shape:
-		'''Bit width and signedness of a value.
+		'''
+		Bit width and signedness of a value.
 
 		Returns
 		-------
@@ -598,7 +690,9 @@ class Value(metaclass = ABCMeta):
 		Shape(width = 8, signed = False)
 		>>> Const(0xaa).shape()
 		Shape(width = 8, signed = False)
+
 		'''
+
 		raise NotImplementedError('.shape has not been implemented')
 
 	def _lhs_signals(self):
@@ -611,12 +705,11 @@ class Value(metaclass = ABCMeta):
 	def _as_const(self):
 		raise TypeError(f'Value {self!r} cannot be evaluated as constant')
 
-	__hash__ = None
-
 
 @final
 class Const(Value):
-	'''A constant, literal integer value.
+	'''
+	A constant, literal integer value.
 
 	Parameters
 	----------
@@ -630,20 +723,21 @@ class Const(Value):
 	----------
 	width : int
 	signed : bool
+
 	'''
+
 	src_loc = None
 
 	@staticmethod
-	def normalize(value: int, shape: Tuple[int, bool]):
-		width, signed = shape
-		mask = (1 << width) - 1
+	def normalize(value: int, shape: tuple[int, bool]):
+		mask = (1 << shape.width) - 1
 		value &= mask
-		if signed and value >> (width - 1):
+		if shape.signed and value >> (shape.width - 1):
 			value |= ~mask
 		return value
 
 	def __init__(
-		self, value: int, shape: Optional[Union[int, Tuple[int, bool]]] = None, *,
+		self, value: int, shape: Optional[Union[int, tuple[int, bool]]] = None, *,
 		src_loc_at: int = 0
 	) -> None:
 		# We deliberately do not call Value.__init__ here.
@@ -653,9 +747,18 @@ class Const(Value):
 		elif isinstance(shape, int):
 			shape = Shape(shape, signed = self.value < 0)
 		else:
+			if isinstance(shape, range) and self.value == shape.stop:
+				warnings.warn(
+					message =
+						f'Value {self.value!r} equals the non-inclusive end of the constant '
+						f'shape {shape!r}; this is likely an off-by-one error',
+					category = SyntaxWarning,
+					stacklevel = 2
+				)
 			shape = Shape.cast(shape, src_loc_at = 1 + src_loc_at)
-		self.width, self.signed = shape
-		self.value = self.normalize(self.value, shape)
+		self.width  = shape.width
+		self.signed = shape.signed
+		self.value  = self.normalize(self.value, shape)
 
 	def shape(self) -> Shape:
 		return Shape(self.width, self.signed)
@@ -672,13 +775,13 @@ class Const(Value):
 
 class AnyValue(Value, DUID):
 	def __init__(
-		self, shape: Union[Shape, int, Tuple[int, bool], range, type, ShapeCastable] , *,
+		self, shape: Union[Shape, int, tuple[int, bool], range, type, ShapeCastable] , *,
 		src_loc_at: int = 0
 	) -> None:
 		super().__init__(src_loc_at = src_loc_at)
-		self.width, self.signed = Shape.cast(shape, src_loc_at = 1 + src_loc_at)
-		if not isinstance(self.width, int) or self.width < 0:
-			raise TypeError(f'Width must be a non-negative integer, not {self.width!r}')
+		shape = Shape.cast(shape, src_loc_at = 1 + src_loc_at)
+		self.width  = shape.width
+		self.signed = shape.signed
 
 	def shape(self) -> Shape:
 		return Shape(self.width, self.signed)
@@ -708,55 +811,53 @@ class Operator(Value):
 
 	def shape(self):
 		def _bitwise_binary_shape(a_shape, b_shape):
-			a_bits, a_sign = a_shape
-			b_bits, b_sign = b_shape
-			if not a_sign and not b_sign:
+			if not a_shape.signed and not b_shape.signed:
 				# both operands unsigned
-				return Shape(max(a_bits, b_bits), False)
-			elif a_sign and b_sign:
+				return unsigned(max(a_shape.width, b_shape.width))
+			elif a_shape.signed and b_shape.signed:
 				# both operands signed
-				return Shape(max(a_bits, b_bits), True)
-			elif not a_sign and b_sign:
+				return signed(max(a_shape.width, b_shape.width))
+			elif not a_shape.signed and b_shape.signed:
 				# first operand unsigned (add sign bit), second operand signed
-				return Shape(max(a_bits + 1, b_bits), True)
+				return signed(max(a_shape.width + 1, b_shape.width))
 			else:
 				# first signed, second operand unsigned (add sign bit)
-				return Shape(max(a_bits, b_bits + 1), True)
+				return signed(max(a_shape.width, b_shape.width + 1))
 
 		op_shapes = list(map(lambda x: x.shape(), self.operands))
 		if len(op_shapes) == 1:
-			(a_width, a_signed), = op_shapes
+			a_shape, = op_shapes
 			if self.operator in ('+', '~'):
-				return Shape(a_width, a_signed)
+				return Shape(a_shape.width, a_shape.signed)
 			if self.operator == '-':
-				return Shape(a_width + 1, True)
+				return Shape(a_shape.width + 1, True)
 			if self.operator in ('b', 'r|', 'r&', 'r^'):
 				return Shape(1, False)
 			if self.operator == 'u':
-				return Shape(a_width, False)
+				return Shape(a_shape.width, False)
 			if self.operator == 's':
-				return Shape(a_width, True)
+				return Shape(a_shape.width, True)
 		elif len(op_shapes) == 2:
-			(a_width, a_signed), (b_width, b_signed) = op_shapes
+			a_shape, b_shape = op_shapes
 			if self.operator in ('+', '-'):
-				width, signed = _bitwise_binary_shape(*op_shapes)
-				return Shape(width + 1, signed)
+				o_shape = _bitwise_binary_shape(*op_shapes)
+				return Shape(o_shape.width + 1, o_shape.signed)
 			if self.operator == '*':
-				return Shape(a_width + b_width, a_signed or b_signed)
+				return Shape(a_shape.width + b_shape.width, a_shape.signed or b_shape.signed)
 			if self.operator == '//':
-				return Shape(a_width + b_signed, a_signed or b_signed)
+				return Shape(a_shape.width + b_shape.signed, a_shape.signed or b_shape.signed)
 			if self.operator == '%':
-				return Shape(b_width, b_signed)
+				return Shape(b_shape.width, b_shape.signed)
 			if self.operator in ('<', '<=', '==', '!=', '>', '>='):
 				return Shape(1, False)
 			if self.operator in ('&', '^', '|'):
 				return _bitwise_binary_shape(*op_shapes)
 			if self.operator == '<<':
-				assert not b_signed
-				return Shape(a_width + 2 ** b_width - 1, a_signed)
+				assert not b_shape.signed
+				return Shape(a_shape.width + 2 ** b_shape.width - 1, a_shape.signed)
 			if self.operator == '>>':
-				assert not b_signed
-				return Shape(a_width, a_signed)
+				assert not b_shape.signed
+				return Shape(a_shape.width, a_shape.signed)
 		elif len(op_shapes) == 3:
 			if self.operator == 'm':
 				s_shape, a_shape, b_shape = op_shapes
@@ -776,7 +877,8 @@ class Operator(Value):
 
 
 def Mux(sel: Value, val1: Value, val0: Value) -> Operator:
-	'''Choose between two values.
+	'''
+	Choose between two values.
 
 	Parameters
 	----------
@@ -790,7 +892,9 @@ def Mux(sel: Value, val1: Value, val0: Value) -> Operator:
 	-------
 	Value, out
 		Output ``Value``. If ``sel`` is asserted, the Mux returns ``val1``, else ``val0``.
+
 	'''
+
 	return Operator('m', [sel, val1, val0])
 
 
@@ -866,7 +970,8 @@ class Part(Value):
 
 @final
 class Cat(Value):
-	'''Concatenate values.
+	'''
+	Concatenate values.
 
 	Form a compound ``Value`` from several smaller ones by concatenation.
 	The first argument occupies the lower bits of the result.
@@ -887,16 +992,28 @@ class Cat(Value):
 	Returns
 	-------
 	Value, inout
-		Resulting ``Value`` obtained by concatentation.
+		Resulting ``Value`` obtained by concatenation.
+
 	'''
+
 	def __init__(self, *args: Iterable[Value], src_loc_at: int = 0) -> None:
 		super().__init__(src_loc_at = src_loc_at)
 		self.parts = []
 		for index, arg in enumerate(flatten(args)):
-			if isinstance(arg, int) and arg not in [0, 1]:
+			if isinstance(arg, Enum) and (not isinstance(type(arg), ShapeCastable) or
+				not hasattr(arg, '_torii_shape_')
+			):
 				warnings.warn(
-					f'Argument #{index + 1} of Cat() is a bare integer {arg} used in bit vector '
-					f'context; consider specifying explicit width using Const({arg}, {bits_for(arg)}) instead',
+					f'Argument #{index + 1} of \'Cat()\' is an enumerated value {arg!r} without '
+					'a defined shape used in a bit vector context; use \'Const\' to specify '
+					'the shape.',
+					SyntaxWarning, stacklevel = 2 + src_loc_at
+				)
+			if isinstance(arg, int) and not isinstance(arg, Enum) and arg not in [0, 1]:
+				warnings.warn(
+					f'Argument #{index + 1} of \'Cat()\' is a bare integer {arg} used in bit vector '
+					f'context; consider specifying the width explicitly using \'Const({arg}, {bits_for(arg)})\' '
+					'instead',
 					SyntaxWarning, stacklevel = 2 + src_loc_at
 				)
 			self.parts.append(Value.cast(arg))
@@ -923,7 +1040,8 @@ class Cat(Value):
 
 @final
 class Repl(Value):
-	'''Replicate a value
+	'''
+	Replicate a value
 
 	An input value is replicated (repeated) several times
 	to be used on the RHS of assignments::
@@ -941,7 +1059,9 @@ class Repl(Value):
 	-------
 	Repl, out
 		Replicated value.
+
 	'''
+
 	def __init__(self, value: Value, count: int, *, src_loc_at: int = 0) -> None:
 		if not isinstance(count, int) or count < 0:
 			raise TypeError(f'Replication count must be a non-negative integer, not {count!r}')
@@ -968,7 +1088,8 @@ class Repl(Value):
 
 # @final
 class Signal(Value, DUID):
-	'''A varying integer value.
+	'''
+	A varying integer value.
 
 	Parameters
 	----------
@@ -1006,6 +1127,7 @@ class Signal(Value, DUID):
 	reset_less : bool
 	attrs : dict
 	decoder : function
+
 	'''
 
 	def __init__(
@@ -1018,30 +1140,56 @@ class Signal(Value, DUID):
 			raise TypeError(f'Name must be a string, not {name!r}')
 		self.name = name or tracer.get_var_name(depth = 2 + src_loc_at, default = '$signal')
 
+		orig_shape = shape
 		if shape is None:
 			shape = unsigned(1)
-		self.width, self.signed = Shape.cast(shape, src_loc_at = 1 + src_loc_at)
+		else:
+			shape = Shape.cast(shape, src_loc_at = 1 + src_loc_at)
+		self.width  = shape.width
+		self.signed = shape.signed
 
-		if isinstance(reset, Enum):
-			reset = reset.value
-		if not isinstance(reset, int):
-			raise TypeError('Reset value has to be an int or an integral Enum')
-
-		reset_width = bits_for(reset, self.signed)
-		if reset != 0 and reset_width > self.width:
-			warnings.warn(
-				f'Reset value {reset!r} requires {reset_width} bits to represent, '
-				f'but the signal only has {self.width} bits',
-				SyntaxWarning, stacklevel = 2 + src_loc_at
+		orig_reset = reset
+		try:
+			reset = Const.cast(reset)
+		except TypeError:
+			raise TypeError(
+				f'Reset value must be a constant-castable expression, not {orig_reset!r}'
 			)
 
-		self.reset = reset
+		# Avoid false positives for all-zeroes and all-ones
+		if orig_reset not in (0, -1):
+			if reset.shape().signed and not self.signed:
+				warnings.warn(
+					message = f'Reset value {orig_reset!r} is signed, but the signal shape is {shape!r}',
+					category = SyntaxWarning,
+					stacklevel = 2
+				)
+			elif (
+				reset.shape().width > self.width or
+				reset.shape().width == self.width and
+				self.signed and not reset.shape().signed
+			):
+				warnings.warn(
+					message = f'Reset value {orig_reset!r} will be truncated to the signal shape {shape!r}',
+					category = SyntaxWarning,
+					stacklevel = 2
+				)
+		self.reset = reset.value
 		self.reset_less = bool(reset_less)
 
+		if isinstance(orig_shape, range) and self.reset == orig_shape.stop:
+			warnings.warn(
+				message =
+					f'Reset value {self.reset!r} equals the non-inclusive end of the signal '
+					f'shape {orig_shape!r}; this is likely an off-by-one error',
+				category = SyntaxWarning,
+				stacklevel = 2
+			)
+
 		self.attrs = OrderedDict(() if attrs is None else attrs)
 
-		if decoder is None and isinstance(shape, type) and issubclass(shape, Enum):
-			decoder = shape
+		if decoder is None and isinstance(orig_shape, type) and issubclass(orig_shape, Enum):
+			decoder = orig_shape
 		if isinstance(decoder, type) and issubclass(decoder, Enum):
 			def enum_decoder(value):
 				try:
@@ -1057,13 +1205,16 @@ class Signal(Value, DUID):
 	# Not a @classmethod because torii.compat requires it.
 	@staticmethod
 	def like(other, *, name = None, name_suffix = None, src_loc_at = 0, **kwargs):
-		'''Create Signal based on another.
+		'''
+		Create Signal based on another.
 
 		Parameters
 		----------
 		other : Value
 			Object to base this Signal on.
+
 		'''
+
 		if name is not None:
 			new_name = str(name)
 		elif name_suffix is not None:
@@ -1094,7 +1245,8 @@ class Signal(Value, DUID):
 
 @final
 class ClockSignal(Value):
-	'''Clock signal for a clock domain.
+	'''
+	Clock signal for a clock domain.
 
 	Any ``ClockSignal`` is equivalent to ``cd.clk`` for a clock domain with the corresponding name.
 	All of these signals ultimately refer to the same signal, but they can be manipulated
@@ -1104,7 +1256,9 @@ class ClockSignal(Value):
 	----------
 	domain : str
 		Clock domain to obtain a clock signal for. Defaults to ``'sync'``.
+
 	'''
+
 	def __init__(self, domain = 'sync', *, src_loc_at = 0):
 		super().__init__(src_loc_at = src_loc_at)
 		if not isinstance(domain, str):
@@ -1128,7 +1282,8 @@ class ClockSignal(Value):
 
 @final
 class ResetSignal(Value):
-	'''Reset signal for a clock domain.
+	'''
+	Reset signal for a clock domain.
 
 	Any ``ResetSignal`` is equivalent to ``cd.rst`` for a clock domain with the corresponding name.
 	All of these signals ultimately refer to the same signal, but they can be manipulated
@@ -1140,7 +1295,9 @@ class ResetSignal(Value):
 		Clock domain to obtain a reset signal for. Defaults to ``'sync'``.
 	allow_reset_less : bool
 		If the clock domain is reset-less, act as a constant ``0`` instead of reporting an error.
+
 	'''
+
 	def __init__(self, domain: str = 'sync', allow_reset_less: bool = False, *, src_loc_at: int = 0):
 		super().__init__(src_loc_at = src_loc_at)
 		if not isinstance(domain, str):
@@ -1164,7 +1321,8 @@ class ResetSignal(Value):
 
 
 class Array(MutableSequence):
-	'''Addressable multiplexer.
+	'''
+	Addressable multiplexer.
 
 	An array is similar to a ``list`` that can also be indexed by ``Value``s;
 	indexing by an integer or a slice works the same as for Python lists,
@@ -1212,7 +1370,9 @@ class Array(MutableSequence):
 			buses[sel].r_en.eq(master.r_en),
 			master.r_data.eq(buses[sel].r_data),
 		]
+
 	'''
+
 	def __init__(self, iterable = ()):
 		self._inner    = list(iterable)
 		self._proxy_at = None
@@ -1251,7 +1411,7 @@ class Array(MutableSequence):
 
 @final
 class ArrayProxy(Value):
-	def __init__(self, elems, index, *, src_loc_at=0):
+	def __init__(self, elems, index, *, src_loc_at = 0):
 		super().__init__(src_loc_at = 1 + src_loc_at)
 		self.elems = elems
 		self.index = Value.cast(index)
@@ -1268,13 +1428,13 @@ class ArrayProxy(Value):
 	def shape(self):
 		unsigned_width = signed_width = 0
 		has_unsigned = has_signed = False
-		for elem_width, elem_signed in (elem.shape() for elem in self._iter_as_values()):
-			if elem_signed:
+		for elem_shape in (elem.shape() for elem in self._iter_as_values()):
+			if elem_shape.signed:
 				has_signed = True
-				signed_width = max(signed_width, elem_width)
+				signed_width = max(signed_width, elem_shape.width)
 			else:
 				has_unsigned = True
-				unsigned_width = max(unsigned_width, elem_width)
+				unsigned_width = max(unsigned_width, elem_shape.width)
 		# The shape of the proxy must be such that it preserves the mathematical value of the array
 		# elements. I.e., shape-wise, an array proxy must be identical to an equivalent mux tree.
 		# To ensure this holds, if the array contains both signed and unsigned values, make sure
@@ -1301,60 +1461,9 @@ class ArrayProxy(Value):
 	def __repr__(self):
 		return f'(proxy (array [{", ".join(map(repr, self.elems))}]) {self.index!r})'
 
-
-# TODO(Torii-0.4): remove
-class UserValue(Value):
-	'''Value with custom lowering.
-
-	A ``UserValue`` is a value whose precise representation does not have to be immediately known,
-	which is useful in certain metaprogramming scenarios. Instead of providing fixed semantics
-	upfront, it is kept abstract for as long as possible, only being lowered to a concrete Torii
-	value when required.
-
-	Note that the ``lower`` method will only be called once; this is necessary to ensure that
-	Torii's view of representation of all values stays internally consistent. If the class
-	deriving from  ``UserValue`` is mutable, then it must ensure that after ``lower`` is called,
-	it is not mutated in a way that changes its representation.
-
-	The following is an incomplete list of actions that, when applied to an ``UserValue`` directly
-	or indirectly, will cause it to be lowered, provided as an illustrative reference:
-
-		* Querying the shape using ``.shape()`` or ``len()``;
-		* Creating a similarly shaped signal using ``Signal.like``;
-		* Indexing or iterating through individual bits;
-		* Adding an assignment to the value to a ``Module`` using ``m.d.<domain> +=``.
-
-	'''
-	@deprecated('instead of `UserValue`, use `ValueCastable`', stacklevel = 3)
-	def __init__(self, *, src_loc_at = 0):
-		super().__init__(src_loc_at = 1 + src_loc_at)
-		self.__lowered = None
-
-	@abstractmethod
-	def lower(self):
-		'''Conversion to a concrete representation.'''
-		pass # :nocov:
-
-	def _lazy_lower(self):
-		if self.__lowered is None:
-			lowered = self.lower()
-			if isinstance(lowered, UserValue):
-				lowered = lowered._lazy_lower()
-			self.__lowered = Value.cast(lowered)
-		return self.__lowered
-
-	def shape(self):
-		return self._lazy_lower().shape()
-
-	def _lhs_signals(self):
-		return self._lazy_lower()._lhs_signals()
-
-	def _rhs_signals(self):
-		return self._lazy_lower()._rhs_signals()
-
-
 class ValueCastable:
-	'''Interface of user-defined objects that can be cast to :class:`Value` s.
+	'''
+	Interface of user-defined objects that can be cast to :class:`Value` s.
 
 	An object deriving from :class:`ValueCastable`` is automatically converted to a :class:`Value`
 	when it is used in a context where a :class:`Value`` is expected. Such objects can implement
@@ -1369,20 +1478,21 @@ class ValueCastable:
 	calls to :meth:`as_value` return the same :class:`Value` representation. If the class deriving
 	from :class:`ValueCastable` is mutable, it is up to the user to ensure that it is not mutated
 	in a way that changes its representation after the first call to :meth:`as_value`.
+
 	'''
-	def __new__(cls, *args, **kwargs):
-		self = super().__new__(cls)
-		if not hasattr(self, 'as_value'):
+
+	def __init_subclass__(cls, **kwargs):
+		if not hasattr(cls, 'as_value'):
 			raise TypeError(f'Class \'{cls.__name__}\' deriving from `ValueCastable` must override '
 							'the `as_value` method')
-		if not hasattr(self.as_value, '_ValueCastable__memoized'):
+		if not hasattr(cls.as_value, '_ValueCastable__memoized'):
 			raise TypeError(f'Class \'{cls.__name__}\' deriving from `ValueCastable` must decorate '
 							'the `as_value` method with the `ValueCastable.lowermethod` decorator')
-		return self
 
 	@staticmethod
 	def lowermethod(func):
-		'''Decorator to memoize lowering methods.
+		'''
+		Decorator to memoize lowering methods.
 
 		Ensures the decorated method is called only once, with subsequent method calls returning
 		the object returned by the first first method call.
@@ -1390,7 +1500,9 @@ class ValueCastable:
 		This decorator is required to decorate the ``as_value`` method of ``ValueCastable``
 		subclasses. This is to ensure that Torii's view of representation of all values stays
 		internally consistent.
+
 		'''
+
 		@functools.wraps(func)
 		def wrapper_memoized(self, *args, **kwargs):
 			# Use `in self.__dict__` instead of `hasattr` to avoid interfering with custom
@@ -1404,12 +1516,15 @@ class ValueCastable:
 
 @final
 class Sample(Value):
-	'''Value from the past.
+	'''
+	Value from the past.
 
 	A ``Sample`` of an expression is equal to the value of the expression ``clocks`` clock edges
 	of the ``domain`` clock back. If that moment is before the beginning of time, it is equal
 	to the value of the expression calculated as if each signal had its reset value.
+
 	'''
+
 	def __init__(self, expr, clocks, domain, *, src_loc_at = 0):
 		super().__init__(src_loc_at = 1 + src_loc_at)
 		self.value  = Value.cast(expr)
@@ -1450,10 +1565,13 @@ def Fell(expr, clocks = 0, domain = None):
 
 @final
 class Initial(Value):
-	'''Start indicator, for model checking.
+	'''
+	Start indicator, for model checking.
 
 	An ``Initial`` signal is ``1`` at the first cycle of model checking, and ``0`` at any other.
+
 	'''
+
 	def __init__(self, *, src_loc_at = 0):
 		super().__init__(src_loc_at = src_loc_at)
 
@@ -1512,12 +1630,17 @@ class Property(Statement, MustUse):
 	_MustUse__warning = UnusedProperty
 
 	def __init__(
-		self, test: ValueCastType, *, _check: Optional[Signal] = None, _en: Optional[Signal] = None, src_loc_at: int = 0
+		self, test: ValueCastType, *, _check: Optional[Signal] = None, _en: Optional[Signal] = None,
+		name: Optional[str] = None, src_loc_at: int = 0
 	) -> None:
 		super().__init__(src_loc_at = src_loc_at)
 		self.test   = Value.cast(test)
 		self._check = _check
 		self._en    = _en
+		self.name   = name
+		if not isinstance(self.name, str) and self.name is not None:
+			raise TypeError(f'Property name must be a string of None, not {self.name!r}')
+
 		if self._check is None:
 			self._check = Signal(reset_less = True, name = f'${self._kind}$check')
 			self._check.src_loc = self.src_loc
@@ -1532,6 +1655,8 @@ class Property(Statement, MustUse):
 		return self.test._rhs_signals()
 
 	def __repr__(self) -> str:
+		if self.name is not None:
+			return f'({self.name}: {self._kind} {self.test!r})'
 		return f'({self._kind} {self.test!r})'
 
 
@@ -1731,6 +1856,8 @@ class ValueKey:
 			))
 		elif isinstance(self.value, Sample):
 			self._hash = hash((ValueKey(self.value.value), self.value.clocks, self.value.domain))
+		elif isinstance(self.value, Repl):
+			self._hash = hash((ValueKey(self.value.value), self.value.count))
 		elif isinstance(self.value, Initial):
 			self._hash = 0
 		else: # :nocov:
@@ -1768,6 +1895,9 @@ class ValueKey:
 		elif isinstance(self.value, Cat):
 			return all(ValueKey(a) == ValueKey(b)
 						for a, b in zip(self.value.parts, other.value.parts))
+		elif isinstance(self.value, Repl):
+			return (ValueKey(self.value.value) == ValueKey(other.value.value) and
+				self.value.count == other.value.count)
 		elif isinstance(self.value, ArrayProxy):
 			return (ValueKey(self.value.index) == ValueKey(other.value.index) and
 					len(self.value.elems) == len(other.value.elems) and
@@ -1798,7 +1928,7 @@ class ValueKey:
 					self.value.start < other.value.start and
 					self.value.end < other.value.end)
 		else: # :nocov:
-			raise TypeError('Object {!r} cannot be used as a key in value collections')
+			raise TypeError(f'Object {other!r} cannot be used as a key in value collections')
 
 	def __repr__(self) -> str:
 		return f'<{__name__}.ValueKey {self.value!r}>'
