@@ -8,15 +8,18 @@ from functools    import wraps
 
 from ..util       import flatten, tracer
 from ..util.units import bits_for
-from .ast         import *
-from .cd          import *
-from .ir          import *
-from .xfrm        import *
+from .ast         import (
+	Assert, Assign, Assume, Cat, Cover, Operator, Signal, SignalDict,
+	Statement, Switch, Value
+)
+from .cd          import ClockDomain
+from .ir          import Elaboratable, Fragment
+from .xfrm        import SampleDomainInjector
 
 __all__ = (
+	'Module',
 	'SyntaxError',
 	'SyntaxWarning',
-	'Module',
 )
 
 
@@ -209,8 +212,7 @@ class Module(_ModuleBuilderRoot, Elaboratable):
 
 	def _check_signed_cond(self, cond):
 		cond = Value.cast(cond)
-		width, signed = cond.shape()
-		if signed:
+		if cond.shape().signed:
 			warnings.warn(
 				'Signed values in If/Elif conditions usually result from inverting '
 				'Python booleans with ~, which leads to unexpected results. '
@@ -303,7 +305,7 @@ class Module(_ModuleBuilderRoot, Elaboratable):
 
 	@contextmanager
 	def Case(self, *patterns):
-		self._check_context('Case', context='Switch')
+		self._check_context('Case', context = 'Switch')
 		src_loc = tracer.get_src_loc(src_loc_at = 1)
 		switch_data = self._get_ctrl('Switch')
 		new_patterns = ()
@@ -311,10 +313,16 @@ class Module(_ModuleBuilderRoot, Elaboratable):
 			if not isinstance(pattern, (int, str, Enum)):
 				raise SyntaxError(f'Case pattern must be an integer, a string, or an enumeration, not {pattern!r}')
 			if isinstance(pattern, str) and any(bit not in '01- \t' for bit in pattern):
-				raise SyntaxError(f'Case pattern \'{pattern}\' must consist of 0, 1, and - (don\'t care) bits, and may include whitespace')
+				raise SyntaxError(
+					f'Case pattern \'{pattern}\' must consist of 0, 1, and - (don\'t care) bits, and may '
+					'include whitespace'
+				)
 			if (isinstance(pattern, str) and
 					len("".join(pattern.split())) != len(switch_data['test'])):
-				raise SyntaxError(f'Case pattern \'{pattern}\' must have the same width as switch value (which is {len(switch_data["test"])})')
+				raise SyntaxError(
+					f'Case pattern \'{pattern}\' must have the same width as switch value '
+					f'(which is {len(switch_data["test"])})'
+				)
 			if isinstance(pattern, int) and bits_for(pattern) > len(switch_data["test"]):
 				warnings.warn(
 					f'Case pattern \'{pattern:b}\' is wider than switch value (which has width {len(switch_data["test"])}); '
