@@ -6,18 +6,21 @@ from collections       import OrderedDict, defaultdict
 from functools         import reduce
 from typing            import Any, Optional, Union
 
-from ._unused          import UnusedMustUse, MustUse
 from ..util            import flatten
 from ..util.decorators import memoize
-from .ast              import *
-from .cd               import *
+from ._unused          import MustUse, UnusedMustUse
+from .ast              import (
+	ClockSignal, ResetSignal, Signal, SignalDict, SignalSet, Statement,
+	Value
+)
+from .cd               import ClockDomain, DomainError
 
 __all__ = (
-	'UnusedElaboratable',
-	'Elaboratable',
 	'DriverConflict',
+	'Elaboratable',
 	'Fragment',
 	'Instance',
+	'UnusedElaboratable',
 )
 
 
@@ -49,8 +52,9 @@ class Fragment:
 			elif hasattr(obj, 'elaborate'):
 				warnings.warn(
 					f'Class {type(obj)!r} is an elaboratable that does not explicitly inherit from '
-					'Elaboratable; doing so would improve diagnostics',
-					category = RuntimeWarning,
+					'Elaboratable; doing so would improve diagnostics\n'
+					'Support for this will be removed in the next release!',
+					category = DeprecationWarning,
 					stacklevel = 2)
 				code = obj.elaborate.__code__
 				new_obj = obj.elaborate(platform)
@@ -89,7 +93,7 @@ class Fragment:
 				if port_dir == dir:
 					yield port
 
-	def add_driver(self, signal, domain=None):
+	def add_driver(self, signal, domain = None):
 		if domain not in self.drivers:
 			self.drivers[domain] = SignalSet()
 		self.drivers[domain].add(signal)
@@ -273,7 +277,7 @@ class Fragment:
 				warnings.warn_explicit(message, DriverConflict, *memory.src_loc)
 
 		# Flatten hierarchy.
-		for subfrag, subfrag_hierarchy in sorted(flatten_subfrags, key=lambda x: x[1]):
+		for subfrag, subfrag_hierarchy in sorted(flatten_subfrags, key = lambda x: x[1]):
 			self._merge_subfragment(subfrag)
 
 		# If we flattened anything, we might be in a situation where we have a driver conflict
@@ -374,7 +378,7 @@ class Fragment:
 				# and there was no chance to add any logic driving it.
 				new_domains.append(value)
 			else:
-				new_fragment = Fragment.get(value, platform=platform)
+				new_fragment = Fragment.get(value, platform = platform)
 				if domain_name not in new_fragment.domains:
 					defined = new_fragment.domains.keys()
 					raise DomainError(
@@ -388,7 +392,7 @@ class Fragment:
 		self._propagate_domains_up()
 		self._propagate_domains_down()
 		self._resolve_hierarchy_conflicts()
-		new_domains = self._create_missing_domains(missing_domain, platform=platform)
+		new_domains = self._create_missing_domains(missing_domain, platform = platform)
 		self._propagate_domains_down()
 		return new_domains
 
@@ -534,7 +538,7 @@ class Fragment:
 			else:
 				self.add_ports(sig, dir = 'i')
 
-	def prepare(self, ports=None, missing_domain=lambda name: ClockDomain(name)):
+	def prepare(self, ports = None, missing_domain = lambda name: ClockDomain(name)):
 		from .xfrm import DomainLowerer, SampleLowerer
 
 		fragment = SampleLowerer()(self)
@@ -567,6 +571,48 @@ class Fragment:
 
 
 class Instance(Fragment):
+	'''
+	Allows for the direct instantiation of external modules, cells, or primitives.
+
+	It accepts the name of the object to instantiate and a collection of keyword arguments
+	that define the ports, attributes, and parameters to it.
+
+	It is defined by a prefix followed by the canonical name of the element the value is setting.
+	For instance, if you have a cell called ``dff`` with ports named ``CLK``, ``D``, and ``Q`` you
+	are able to instantiate it as follows:
+
+	.. code-block:: python
+
+		dff = Instance(
+			'dff',
+			i_D   = sig_in,
+			i_CLK = clk,
+			o_Q   = sig_out,
+		)
+
+	The meaning of the prefix for the arguments are as follows:
+
+	+---------+----------------------------+
+	| Prefix  | Corresponding Type         |
+	+=========+============================+
+	| ``a_``  | Attribute                  |
+	+---------+----------------------------+
+	| ``p_``  | Parameter                  |
+	+---------+----------------------------+
+	| ``i_``  | Input Port/Signal          |
+	+---------+----------------------------+
+	| ``o_``  | Output Port/Signal         |
+	+---------+----------------------------+
+	| ``io_`` | Bi-directional Port/Signal |
+	+---------+----------------------------+
+
+	Parameters
+	----------
+	type: str
+		The name/type of object to instantiate
+
+	'''
+
 	def __init__(self, type, *args, **kwargs):
 		super().__init__()
 
@@ -582,8 +628,10 @@ class Instance(Fragment):
 			elif kind in ('i', 'o', 'io'):
 				self.named_ports[name] = (Value.cast(value), kind)
 			else:
-				raise NameError(f'Instance argument {(kind, name, value)!r} should be a tuple (kind, name, value) '
-								'where kind is one of \'a\', \'p\', \'i\', \'o\', or \'io\'')
+				raise NameError(
+					f'Instance argument {(kind, name, value)!r} should be a tuple (kind, name, value) '
+					'where kind is one of \'a\', \'p\', \'i\', \'o\', or \'io\''
+				)
 
 		for kw, arg in kwargs.items():
 			if kw.startswith('a_'):
@@ -592,10 +640,12 @@ class Instance(Fragment):
 				self.parameters[kw[2:]] = arg
 			elif kw.startswith('i_'):
 				self.named_ports[kw[2:]] = (Value.cast(arg), 'i')
-			elif kw.startswith("o_"):
+			elif kw.startswith('o_'):
 				self.named_ports[kw[2:]] = (Value.cast(arg), 'o')
-			elif kw.startswith("io_"):
+			elif kw.startswith('io_'):
 				self.named_ports[kw[3:]] = (Value.cast(arg), 'io')
 			else:
-				raise NameError(f'Instance keyword argument {kw} = {arg!r} does not start with one of '
-								'\'a_\', \'p_\', \'i_\', \'o_\', or \'io_\'')
+				raise NameError(
+					f'Instance keyword argument {kw} = {arg!r} does not start with one of '
+					'\'a_\', \'p_\', \'i_\', \'o_\', or \'io_\''
+				)
