@@ -3,17 +3,16 @@
 from collections import OrderedDict
 from enum        import Enum
 from functools   import reduce, wraps
-from typing      import Any, Generator, Iterable, Optional, Tuple, Union
+from typing      import Any, Generator, Iterable, Optional, Union
 
-from ..util      import union
-from ..util      import tracer
-from .ast        import *
+from ..util      import tracer, union
+from .ast        import Cat, Shape, Signal, SignalSet, Value, ValueCastable
 
 __all__ = (
-	'Direction',
-	'DIR_NONE',
-	'DIR_FANOUT',
 	'DIR_FANIN',
+	'DIR_FANOUT',
+	'DIR_NONE',
+	'Direction',
 	'Layout',
 	'Record',
 )
@@ -35,7 +34,7 @@ class Layout:
 
 	# TODO: The `Any` type is not correct but the types need to be refactored again eventually to fix it
 	def __init__(
-		self, fields: Iterable[Union[Tuple[str, Any], Tuple[str, Any, Direction]]], *,
+		self, fields: Iterable[Union[tuple[str, Any], tuple[str, Any, Direction]]], *,
 		src_loc_at: int = 0
 	) -> None:
 		self.fields = OrderedDict()
@@ -58,7 +57,9 @@ class Layout:
 					# Check provided shape by calling Shape.cast and checking for exception
 					Shape.cast(shape, src_loc_at = 1 + src_loc_at)
 				except Exception:
-					raise TypeError(f'Field {field!r} has invalid shape: should be castable to Shape or a list of fields of a nested record')
+					raise TypeError(
+						f'Field {field!r} has invalid shape: should be castable to Shape or a list of ''fields of a nested record'
+					)
 			if name in self.fields:
 				raise NameError(f'Field {field!r} has a name that is already present in the layout')
 			self.fields[name] = (shape, direction)
@@ -73,7 +74,7 @@ class Layout:
 
 		return self.fields[item]
 
-	def __iter__(self) -> Generator[Tuple[str, Any, Direction], None, None]:
+	def __iter__(self) -> Generator[tuple[str, Any, Direction], None, None]:
 		for name, (shape, dir) in self.fields.items():
 			yield (name, shape, dir)
 
@@ -167,7 +168,9 @@ class Record(ValueCastable):
 					reference = 'Unnamed record'
 				else:
 					reference = f'Record \'{self.name}\''
-				raise AttributeError(f'{reference} does not have a field \'{item}\'. Did you mean one of: {", ".join(self.fields)}?') from None
+				raise AttributeError(
+					f'{reference} does not have a field \'{item}\'. Did you mean one of: {", ".join(self.fields)}?'
+				) from None
 		elif isinstance(item, tuple):
 			return Record(self.layout[item], fields = {
 				field_name: field_value
@@ -182,7 +185,9 @@ class Record(ValueCastable):
 					reference = 'Unnamed record'
 				else:
 					reference = f'Record \'{self.name}\''
-				raise AttributeError(f'{reference} does not have a field \'{item}\'. Did you mean one of: {", ".join(self.fields)}?') from None
+				raise AttributeError(
+					f'{reference} does not have a field \'{item}\'. Did you mean one of: {", ".join(self.fields)}?'
+				) from None
 
 	@ValueCastable.lowermethod
 	def as_value(self) -> Cat:
@@ -252,7 +257,7 @@ class Record(ValueCastable):
 			if isinstance(shape, Layout):
 				sub_include = include[field] if include and field in include else None
 				sub_exclude = exclude[field] if exclude and field in exclude else None
-				stmts += item.connect(*subord_items, include=sub_include, exclude=sub_exclude)
+				stmts += item.connect(*subord_items, include = sub_include, exclude = sub_exclude)
 			else:
 				if direction == DIR_FANOUT:
 					stmts += [ sub_item.eq(item) for sub_item in subord_items ]
