@@ -4,23 +4,34 @@ from abc             import ABCMeta, abstractmethod
 from collections     import OrderedDict
 from collections.abc import Iterable
 
-from ..util          import flatten
-from ..util          import tracer
-from .ast            import *
-from .ast            import _StatementList
-from .cd             import *
-from .ir             import *
-from .rec            import *
+from ..util          import flatten, tracer
+from .ast            import (
+	AnyConst, AnySeq, ArrayProxy, Assert, Assign, Assume, Cat,
+	ClockSignal, Const, Cover, Initial, Mux, Operator, Part,
+	Property, Repl, ResetSignal, Sample, Signal, SignalDict,
+	SignalSet, Slice, Statement, Switch, Value, ValueDict,
+	_StatementList
+)
+from .cd             import DomainError
+from .ir             import Elaboratable, Fragment, Instance
 
 __all__ = (
-	'ValueVisitor', 'ValueTransformer',
-	'StatementVisitor', 'StatementTransformer',
+	'DomainCollector',
+	'DomainLowerer',
+	'DomainRenamer',
+	'EnableInserter',
 	'FragmentTransformer',
+	'LHSGroupAnalyzer',
+	'LHSGroupFilter',
+	'ResetInserter',
+	'SampleDomainInjector',
+	'SampleLowerer',
+	'StatementTransformer',
+	'StatementVisitor',
+	'SwitchCleaner',
 	'TransformedElaboratable',
-	'DomainCollector', 'DomainRenamer', 'DomainLowerer',
-	'SampleDomainInjector', 'SampleLowerer',
-	'SwitchCleaner', 'LHSGroupAnalyzer', 'LHSGroupFilter',
-	'ResetInserter', 'EnableInserter',
+	'ValueTransformer',
+	'ValueVisitor',
 )
 
 
@@ -116,9 +127,6 @@ class ValueVisitor(metaclass = ABCMeta):
 			new_value = self.on_Sample(value)
 		elif type(value) is Initial:
 			new_value = self.on_Initial(value)
-		elif isinstance(value, UserValue):
-			# Uses `isinstance()` and not `type() is` to allow inheriting.
-			new_value = self.on_value(value._lazy_lower())
 		else:
 			new_value = self.on_unknown_value(value)
 		if isinstance(new_value, Value) and self.replace_value_src_loc(value, new_value):
@@ -244,13 +252,22 @@ class StatementTransformer(StatementVisitor):
 		return Assign(self.on_value(stmt.lhs), self.on_value(stmt.rhs))
 
 	def on_Assert(self, stmt):
-		return Assert(self.on_value(stmt.test), _check = stmt._check, _en = stmt._en)
+		return Assert(
+			self.on_value(stmt.test), _check = stmt._check,
+			_en = stmt._en, name = stmt.name
+		)
 
 	def on_Assume(self, stmt):
-		return Assume(self.on_value(stmt.test), _check = stmt._check, _en = stmt._en)
+		return Assume(
+			self.on_value(stmt.test), _check = stmt._check,
+			_en = stmt._en, name = stmt.name
+		)
 
 	def on_Cover(self, stmt):
-		return Cover(self.on_value(stmt.test), _check=stmt._check, _en=stmt._en)
+		return Cover(
+			self.on_value(stmt.test), _check = stmt._check,
+			_en = stmt._en, name = stmt.name
+		)
 
 	def on_Switch(self, stmt):
 		cases = OrderedDict((k, self.on_statement(s)) for k, s in stmt.cases.items())
@@ -483,7 +500,7 @@ class DomainRenamer(FragmentTransformer, ValueTransformer, StatementTransformer)
 
 
 class DomainLowerer(FragmentTransformer, ValueTransformer, StatementTransformer):
-	def __init__(self, domains=None):
+	def __init__(self, domains = None):
 		self.domains = domains
 
 	def _resolve(self, domain, context):
@@ -722,7 +739,7 @@ class _ControlInserter(FragmentTransformer):
 	def _insert_control(self, fragment, domain, signals):
 		raise NotImplementedError # :nocov:
 
-	def __call__(self, value, *, src_loc_at=0):
+	def __call__(self, value, *, src_loc_at = 0):
 		self.src_loc = tracer.get_src_loc(src_loc_at = src_loc_at)
 		return super().__call__(value, src_loc_at = 1 + src_loc_at)
 
