@@ -1,14 +1,16 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from typing  import Optional, Literal
+from typing import Literal, Optional
 
-from ..      import Elaboratable, Module, Signal, ClockDomain, ClockSignal, ResetSignal
+from ..     import (
+	ClockDomain, ClockSignal, Elaboratable, Module, ResetSignal, Signal
+)
 
 __all__ = (
-	'FFSynchronizer',
 	'AsyncFFSynchronizer',
-	'ResetSynchronizer',
+	'FFSynchronizer',
 	'PulseSynchronizer',
+	'ResetSynchronizer',
 )
 
 
@@ -20,7 +22,8 @@ def _check_stages(stages: int):
 
 
 class FFSynchronizer(Elaboratable):
-	'''Resynchronise a signal to a different clock domain.
+	'''
+	Resynchronize a signal to a different clock domain.
 
 	Consists of a chain of flip-flops. Eliminates metastabilities at the output, but provides
 	no other guarantee as to the safe domain-crossing of a signal.
@@ -28,9 +31,9 @@ class FFSynchronizer(Elaboratable):
 	Parameters
 	----------
 	i : Signal(n), in
-		Signal to be resynchronised.
+		Signal to be resynchronized.
 	o : Signal(n), out
-		Signal connected to synchroniser output.
+		Signal connected to synchronizer output.
 	o_domain : str
 		Name of output clock domain.
 	reset : int
@@ -60,7 +63,7 @@ class FFSynchronizer(Elaboratable):
 		- Your design features warm (non-power-on) resets of ``o_domain``, so the one-time
 		  initialization at power on is insufficient;
 		- Your design features a sequenced reset, and the :class:`FFSynchronizer` must maintain
-		  its reset value until ``o_domain`` reset specifically is deasserted.
+		  its reset value until ``o_domain`` reset specifically is de-asserted.
 
 		:class:`FFSynchronizer` is reset by the ``o_domain`` reset only.
 
@@ -68,7 +71,9 @@ class FFSynchronizer(Elaboratable):
 	------------------
 	Define the ``get_ff_sync`` platform method to override the implementation of
 	:class:`FFSynchronizer`, e.g. to instantiate library cells directly.
+
 	''' # noqa: E101
+
 	def __init__(
 		self, i: Signal, o: Signal, *, o_domain: str = 'sync', reset: int = 0,
 		reset_less: bool = True, stages: int = 2, max_input_delay: Optional[float] = None
@@ -90,7 +95,9 @@ class FFSynchronizer(Elaboratable):
 			return platform.get_ff_sync(self)
 
 		if self._max_input_delay is not None:
-			raise NotImplementedError(f'Platform \'{type(platform).__name__}\' does not support constraining input delay for FFSynchronizer')
+			raise NotImplementedError(
+				f'Platform \'{type(platform).__name__}\' does not support constraining input delay for FFSynchronizer'
+			)
 
 		m = Module()
 		flops = [
@@ -104,10 +111,11 @@ class FFSynchronizer(Elaboratable):
 
 
 class AsyncFFSynchronizer(Elaboratable):
-	'''Synchronize deassertion of an asynchronous signal.
+	'''
+	Synchronize de-assertion of an asynchronous signal.
 
-	The signal driven by the :class:`AsyncFFSynchronizer` is asserted asynchronously and deasserted
-	synchronously, eliminating metastability during deassertion.
+	The signal driven by the :class:`AsyncFFSynchronizer` is asserted asynchronously and de-asserted
+	synchronously, eliminating metastability during de-assertion.
 
 	This synchronizer is primarily useful for resets and reset-like signals.
 
@@ -121,7 +129,7 @@ class AsyncFFSynchronizer(Elaboratable):
 		Name of clock domain to synchronize to.
 	stages : int, >=2
 		Number of synchronization stages between input and output. The lowest safe number is 2,
-		with higher numbers reducing MTBF further, at the cost of increased deassertion latency.
+		with higher numbers reducing MTBF further, at the cost of increased de-assertion latency.
 	async_edge : str
 		The edge of the input signal which causes the output to be set. Must be one of "pos" or "neg".
 	max_input_delay : None or float
@@ -132,7 +140,9 @@ class AsyncFFSynchronizer(Elaboratable):
 	------------------
 	Define the ``get_async_ff_sync`` platform method to override the implementation of
 	:class:`AsyncFFSynchronizer`, e.g. to instantiate library cells directly.
+
 	'''
+
 	def __init__(
 		self, i: Signal, o: Signal, *, o_domain: str = 'sync', stages: int = 2,
 		async_edge: Literal['pos', 'neg'] = 'pos', max_input_delay: Optional[float] = None
@@ -189,13 +199,14 @@ class AsyncFFSynchronizer(Elaboratable):
 
 
 class ResetSynchronizer(Elaboratable):
-	'''Synchronize deassertion of a clock domain reset.
+	'''
+	Synchronize de-assertion of a clock domain reset.
 
 	The reset of the clock domain driven by the :class:`ResetSynchronizer` is asserted
-	asynchronously and deasserted synchronously, eliminating metastability during deassertion.
+	asynchronously and de-asserted synchronously, eliminating metastability during de-assertion.
 
 	The driven clock domain could use a reset that is asserted either synchronously or
-	asynchronously; a reset is always deasserted synchronously. A domain with an asynchronously
+	asynchronously; a reset is always de-asserted synchronously. A domain with an asynchronously
 	asserted reset is useful if the clock of the domain may be gated, yet the domain still
 	needs to be reset promptly; otherwise, synchronously asserted reset (the default) should
 	be used.
@@ -208,7 +219,7 @@ class ResetSynchronizer(Elaboratable):
 		Name of clock domain to reset.
 	stages : int, >=2
 		Number of synchronization stages between input and output. The lowest safe number is 2,
-		with higher numbers reducing MTBF further, at the cost of increased deassertion latency.
+		with higher numbers reducing MTBF further, at the cost of increased de-assertion latency.
 	max_input_delay : None or float
 		Maximum delay from the input signal's clock to the first synchronization stage, in seconds.
 		If specified and the platform does not support it, elaboration will fail.
@@ -217,7 +228,9 @@ class ResetSynchronizer(Elaboratable):
 	------------------
 	Define the ``get_reset_sync`` platform method to override the implementation of
 	:class:`ResetSynchronizer`, e.g. to instantiate library cells directly.
+
 	'''
+
 	def __init__(
 		self, arst: Signal, *, domain: str = 'sync', stages: int = 2,
 		max_input_delay: Optional[float] = None
@@ -242,7 +255,8 @@ class ResetSynchronizer(Elaboratable):
 
 
 class PulseSynchronizer(Elaboratable):
-	'''A one-clock pulse on the input produces a one-clock pulse on the output.
+	'''
+	A one-clock pulse on the input produces a one-clock pulse on the output.
 
 	If the output clock is faster than the input clock, then the input may be safely asserted at
 	100% duty cycle. Otherwise, if the clock ratio is ``n``:1, the input may be asserted at most
@@ -257,8 +271,10 @@ class PulseSynchronizer(Elaboratable):
 		Name of output clock domain.
 	stages : int, >=2
 		Number of synchronization stages between input and output. The lowest safe number is 2,
-		with higher numbers reducing MTBF further, at the cost of increased deassertion latency.
+		with higher numbers reducing MTBF further, at the cost of increased de-assertion latency.
+
 	'''
+
 	def __init__(self, i_domain: str, o_domain: str, *, stages: int = 2) -> None:
 		_check_stages(stages)
 
