@@ -1,21 +1,21 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-'''First-in first-out queues.'''
+''' First-in first-out queues. '''
 
 from typing       import Union
 
 from ..           import Elaboratable, Memory, Module, Mux, ResetSignal, Signal
-from ..asserts    import *
+from ..asserts    import Assert, Assume, Initial
 from ..util.units import log2_int
 from .cdc         import AsyncFFSynchronizer, FFSynchronizer
 from .coding      import GrayDecoder, GrayEncoder
 
 __all__ = (
+	'AsyncFIFO',
+	'AsyncFIFOBuffered',
 	'FIFOInterface',
 	'SyncFIFO',
 	'SyncFIFOBuffered',
-	'AsyncFIFO',
-	'AsyncFIFOBuffered',
 )
 
 
@@ -153,7 +153,7 @@ class SyncFIFO(Elaboratable, FIFOInterface):
 		do_read  = self.r_rdy & self.r_en
 		do_write = self.w_rdy & self.w_en
 
-		storage = Memory(width=self.width, depth=self.depth)
+		storage = Memory(width = self.width, depth = self.depth)
 		w_port  = m.submodules.w_port = storage.write_port()
 		r_port  = m.submodules.r_port = storage.read_port(
 			domain = 'comb' if self.fwft else 'sync', transparent = self.fwft)
@@ -215,7 +215,7 @@ class SyncFIFOBuffered(Elaboratable, FIFOInterface):
 		description = '''
 		Buffered synchronous first in, first out queue.
 
-		This queue's interface is identical to :class:`SyncFIFO` configured as ``fwft=True``, but it
+		This queue's interface is identical to :class:`SyncFIFO` configured as ``fwft = True``, but it
 		does not use asynchronous memory reads, which are incompatible with FPGA block RAMs.
 
 		In exchange, the latency between an entry being written to an empty queue and that entry
@@ -304,7 +304,7 @@ class AsyncFIFO(Elaboratable, FIFOInterface):
 			Always set.
 		'''.strip(),
 		attributes = '',
-		r_data_valid='Valid if ``r_rdy`` is asserted.',
+		r_data_valid = 'Valid if ``r_rdy`` is asserted.',
 		r_attributes = '''
 		r_rst : Signal(1), out
 			Asserted, for at least one read-domain clock cycle, after the FIFO has been reset by
@@ -322,7 +322,9 @@ class AsyncFIFO(Elaboratable, FIFOInterface):
 				depth_bits = log2_int(depth, need_pow2 = exact_depth)
 				depth = 1 << depth_bits
 			except ValueError:
-				raise ValueError(f'AsyncFIFO only supports depths that are powers of 2; requested exact depth {depth} is not') from None
+				raise ValueError(
+					f'AsyncFIFO only supports depths that are powers of 2; requested exact depth {depth} is not'
+				) from None
 		else:
 			depth_bits = 0
 		super().__init__(width = width, depth = depth, fwft = True)
@@ -355,7 +357,7 @@ class AsyncFIFO(Elaboratable, FIFOInterface):
 		m.d[self._w_domain] += produce_w_bin.eq(produce_w_nxt)
 
 		# Note: Both read-domain counters must be reset_less (see comments below)
-		consume_r_bin = Signal(self._ctr_bits, reset_less=True)
+		consume_r_bin = Signal(self._ctr_bits, reset_less = True)
 		consume_r_nxt = Signal(self._ctr_bits)
 		m.d.comb += consume_r_nxt.eq(consume_r_bin + do_read)
 		m.d[self._r_domain] += consume_r_bin.eq(consume_r_nxt)
@@ -402,7 +404,7 @@ class AsyncFIFO(Elaboratable, FIFOInterface):
 		m.d[self._w_domain] += self.w_level.eq((produce_w_bin - consume_w_bin))
 		m.d.comb += self.r_level.eq((produce_r_bin - consume_r_bin))
 
-		storage = Memory(width=self.width, depth=self.depth)
+		storage = Memory(width = self.width, depth = self.depth)
 		w_port  = m.submodules.w_port = storage.write_port(domain = self._w_domain)
 		r_port  = m.submodules.r_port = storage.read_port(
 			domain = self._r_domain, transparent = False
@@ -503,7 +505,8 @@ class AsyncFIFOBuffered(Elaboratable, FIFOInterface):
 				depth = (1 << depth_bits) + 1
 			except ValueError:
 				raise ValueError(
-					f'AsyncFIFOBuffered only supports depths that are one higher than powers of 2; requested exact depth {depth} is not'
+					'AsyncFIFOBuffered only supports depths that are one higher than powers of 2; '
+					f'requested exact depth {depth} is not'
 				) from None
 		super().__init__(width = width, depth = depth, fwft = True)
 
@@ -534,7 +537,9 @@ class AsyncFIFOBuffered(Elaboratable, FIFOInterface):
 		m.d[self._r_domain] += self.r_level.eq(fifo.r_level + r_consume_buffered)
 
 		w_consume_buffered = Signal()
-		m.submodules.consume_buffered_cdc = FFSynchronizer(r_consume_buffered, w_consume_buffered, o_domain=self._w_domain, stages=4)
+		m.submodules.consume_buffered_cdc = FFSynchronizer(
+			r_consume_buffered, w_consume_buffered, o_domain = self._w_domain, stages = 4
+		)
 		m.d.comb += self.w_level.eq(fifo.w_level + w_consume_buffered)
 
 		with m.If(self.r_en | ~self.r_rdy):
