@@ -57,7 +57,7 @@ class Pin(Record):
 	or tristate buffers that may include a 1:n gearbox. (A 1:2 gearbox is typically called 'DDR'.)
 
 	A :class:`Pin` is identical to a :class:`Record` that uses the corresponding :meth:`pin_layout`
-	except that it allos accessing the parameters like ``width`` as attributes. It is legal to use
+	except that it allows accessing the parameters like ``width`` as attributes. It is legal to use
 	a plain :class:`Record` anywhere a :class:`Pin` is used, provided that these attributes are
 	not necessary.
 
@@ -86,7 +86,7 @@ class Pin(Record):
 	i_clk:
 		I/O buffer input clock. Synchronizes `i*`. Present if ``xdr`` is nonzero.
 	i_fclk:
-		I/O buffer input fast clock. Synchronizes `i*` on higer gearbox ratios. Present if ``xdr``
+		I/O buffer input fast clock. Synchronizes `i*` on higher gearbox ratios. Present if ``xdr``
 		is greater than 2.
 	i : Signal, out
 		I/O buffer input, without gearing. Present if ``dir = 'i'`` or ``dir = 'io'``, and ``xdr`` is
