@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from .. import Elaboratable, Signal, Module
+from .. import Elaboratable, Module, Signal
 
 __all__ = (
 	'RoundRobin',
@@ -8,7 +8,8 @@ __all__ = (
 
 
 class RoundRobin(Elaboratable):
-	'''Round-robin scheduler.
+	'''
+	Round-robin scheduler.
 
 	For a given set of requests, the round-robin scheduler will
 	grant one request. Once it grants a request, if any other
@@ -32,9 +33,11 @@ class RoundRobin(Elaboratable):
 		Number of the granted request. Does not change if there are no
 		active requests.
 	valid : Signal(), out
-		Asserted if grant corresponds to an active request. Deasserted
+		Asserted if grant corresponds to an active request. De-asserted
 		otherwise, i.e. if no requests are active.
+
 	'''
+
 	def __init__(self, *, count: int) -> None:
 		if not isinstance(count, int) or count < 0:
 			raise ValueError(f'Count must be a non-negative integer, not {count!r}')
