@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from .bus   import *
-from .event import *
+from .bus   import Decoder, Element, Interface, Multiplexer
+from .event import EventMonitor
 
 __all__ = (
-	'Element',
-	'Interface',
 	'Decoder',
-	'Multiplexer',
+	'Element',
 	'EventMonitor',
+	'Interface',
+	'Multiplexer',
 )
