@@ -1,20 +1,23 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 from bisect        import bisect_left, bisect_right
-from typing        import Generator, Iterable, List, Optional, Tuple, Union
+from typing        import Generator, Iterable, Optional, Union
 
 from ...util.units import bits_for
 
 __all__ = (
-	'ResourceInfo',
 	'MemoryMap',
+	'ResourceInfo',
 )
 
 class _RangeMap:
-	'''Range map.
+	'''
+	Range map.
 
 	A range map is a mapping from non-overlapping ranges to arbitrary values.
+
 	'''
+
 	def __init__(self) -> None:
 		self._keys   = []
 		self._values = dict()
@@ -41,18 +44,19 @@ class _RangeMap:
 			if point >= point_range.start and point < point_range.stop:
 				return self._values[point_range]
 
-	def overlaps(self, key: range) -> List[object]:
+	def overlaps(self, key: range) -> list[object]:
 		start_idx = bisect_right(self._stops, key.start)
 		stop_idx  = bisect_left(self._starts, key.stop)
 		return [self._values[key] for key in self._keys[start_idx:stop_idx]]
 
-	def items(self) -> Generator[Tuple[range, object], None, None]:
+	def items(self) -> Generator[tuple[range, object], None, None]:
 		for key in self._keys:
 			yield (key, self._values[key])
 
 
 class ResourceInfo:
-	'''Resource metadata.
+	'''
+	Resource metadata.
 
 	A wrapper class for resource objects, with their assigned name and address range.
 
@@ -72,7 +76,9 @@ class ResourceInfo:
 		Amount of data bits accessed at each address. It may be equal to the data width of the
 		memory map from which this :class:`ResourceInfo` was obtained, or less if the resource
 		is located behind a window that uses sparse addressing.
+
 	'''
+
 	def __init__(
 		self, resource: object, name: Union[str, Iterable[str]], start: int, end: int, width: int
 	) -> None:
@@ -98,7 +104,7 @@ class ResourceInfo:
 		return self._resource
 
 	@property
-	def name(self) -> Tuple[str]:
+	def name(self) -> tuple[str]:
 		return self._name
 
 	@property
@@ -115,7 +121,8 @@ class ResourceInfo:
 
 
 class MemoryMap:
-	'''Memory map.
+	'''
+	Memory map.
 
 	A memory map is a hierarchical description of an address space, describing the structure of
 	address decoders of peripherals as well as bus bridges. It is built by adding resources
@@ -143,7 +150,9 @@ class MemoryMap:
 		``2 ** alignment``.
 	name : str
 		Name of the address range. Optional.
+
 	'''
+
 	def __init__(
 		self, *, addr_width: int, data_width: int, alignment: int = 0, name: Optional[str] = None
 	) -> None:
@@ -199,11 +208,14 @@ class MemoryMap:
 		return self._name
 
 	def freeze(self) -> None:
-		'''Freeze the memory map.
+		'''
+		Freeze the memory map.
 
 		Once the memory map is frozen, its visible state becomes immutable. Resources and windows
 		cannot be added anymore, and its address width cannot be extended further.
+
 		'''
+
 		self._frozen = True
 
 	@staticmethod
@@ -213,7 +225,8 @@ class MemoryMap:
 		return value
 
 	def align_to(self, alignment: int) -> int:
-		'''Align the implicit next address.
+		'''
+		Align the implicit next address.
 
 		Arguments
 		---------
@@ -224,7 +237,9 @@ class MemoryMap:
 		Return value
 		------------
 		Implicit next address.
+
 		'''
+
 		if not isinstance(alignment, int) or alignment < 0:
 			raise ValueError(f'Alignment must be a non-negative integer, not {alignment!r}')
 		self._next_addr = self._align_up(self._next_addr, max(alignment, self.alignment))
@@ -272,8 +287,9 @@ class MemoryMap:
 	def add_resource(
 		self, resource: object, *, name: str, size: int, addr: Optional[int] = None,
 		alignment: Optional[int] = None, extend: bool = False
-	) -> Tuple[int, int]:
-		'''Add a resource.
+	) -> tuple[int, int]:
+		'''
+		Add a resource.
 
 		A resource is any device on the bus that is a destination for bus transactions, e.g.
 		a register or a memory block.
@@ -311,13 +327,18 @@ class MemoryMap:
 		windows that have already been added, or would be out of bounds;
 		- the resource has already been added to this memory map;
 		- the name of the resource is already present in the namespace of this memory map;
+
 		'''
+
 		if self._frozen:
 			raise ValueError(f'Memory map has been frozen. Cannot add resource {resource!r}')
 
 		if id(resource) in self._resources:
 			_, _, addr_range = self._resources[id(resource)]
-			raise ValueError(f'Resource {resource!r} is already added at address range {addr_range.start:#x}..{addr_range.stop:#x}')
+			raise ValueError(
+				f'Resource {resource!r} is already added at address range '
+				f'{addr_range.start:#x}..{addr_range.stop:#x}'
+			)
 
 		if not isinstance(name, str) or not name:
 			raise TypeError(f'Name must be a non-empty string, not {name!r}')
@@ -339,7 +360,8 @@ class MemoryMap:
 		return (addr_range.start, addr_range.stop)
 
 	def resources(self):
-		'''Iterate local resources and their address ranges.
+		'''
+		Iterate local resources and their address ranges.
 
 		Non-recursively iterate resources in ascending order of their address.
 
@@ -347,15 +369,18 @@ class MemoryMap:
 		------------
 		A tuple ``resource, name, (start, end)`` describing the address range assigned to the
 		resource.
+
 		'''
+
 		for resource, resource_name, resource_range in self._resources.values():
 			yield (resource, resource_name, (resource_range.start, resource_range.stop))
 
 	def add_window(
 		self, window: 'MemoryMap', *, addr: Optional[int] = None, sparse: Optional[int] = None,
 		extend: bool = False
-	) -> Tuple[int, int, int]:
-		'''Add a window.
+	) -> tuple[int, int, int]:
+		'''
+		Add a window.
 
 		A window is a device on a bus that provides access to a different bus, i.e. a bus bridge.
 		It performs address translation, such that the devices on a subordinate bus have different
@@ -408,7 +433,9 @@ class MemoryMap:
 		- the name of the added memory map is already present in the namespace of this memory map;
 		- the added memory map has no name, and the name of one of its subordinate resources or
 		windows is already present in the namespace of this memory map;
+
 		'''
+
 		if not isinstance(window, MemoryMap):
 			raise TypeError(f'Window must be a MemoryMap, not {window!r}')
 
@@ -475,7 +502,8 @@ class MemoryMap:
 		return addr_range.start, addr_range.stop, addr_range.step
 
 	def windows(self):
-		'''Iterate local windows and their address ranges.
+		'''
+		Iterate local windows and their address ranges.
 
 		Non-recursively iterate windows in ascending order of their address.
 
@@ -485,12 +513,15 @@ class MemoryMap:
 		the window. When bridging buses of unequal data width, ``ratio`` is the amount of
 		contiguous addresses on the narrower bus that are accessed for each transaction on
 		the wider bus. Otherwise, it is always 1.
+
 		'''
+
 		for window, window_range in self._windows.values():
 			yield (window, (window_range.start, window_range.stop, window_range.step))
 
-	def window_patterns(self) -> Generator[Tuple[object, Tuple[str, int]], None, None]:
-		'''Iterate local windows and patterns that match their address ranges.
+	def window_patterns(self) -> Generator[tuple[object, tuple[str, int]], None, None]:
+		'''
+		Iterate local windows and patterns that match their address ranges.
 
 		Non-recursively iterate windows in ascending order of their address.
 
@@ -502,7 +533,9 @@ class MemoryMap:
 		buses of unequal data width, ``ratio`` is the amount of contiguous addresses on
 		the narrower bus that are accessed for each transaction on the wider bus. Otherwise,
 		it is always 1.
+
 		'''
+
 		for window, window_range in self._windows.values():
 			const_bits = self.addr_width - window.addr_width
 			if const_bits > 0:
@@ -528,7 +561,8 @@ class MemoryMap:
 		return ResourceInfo(resource_info.resource, name, start, start + size, width)
 
 	def all_resources(self) -> Generator[ResourceInfo, None, None]:
-		'''Iterate all resources and their address ranges.
+		'''
+		Iterate all resources and their address ranges.
 
 		Recursively iterate all resources in ascending order of their address, performing address
 		translation for resources that are located behind a window.
@@ -536,7 +570,9 @@ class MemoryMap:
 		Yield values
 		------------
 		An instance of :class:`ResourceInfo` describing the resource and its address range.
+
 		'''
+
 		for addr_range, assignment in self._ranges.items():
 			if id(assignment) in self._resources:
 				_, resource_name, _ = self._resources[id(assignment)]
@@ -550,7 +586,8 @@ class MemoryMap:
 				assert False # :nocov:
 
 	def find_resource(self, resource: object) -> ResourceInfo:
-		'''Find address range corresponding to a resource.
+		'''
+		Find address range corresponding to a resource.
 
 		Recursively find the address range of a resource, performing address translation for
 		resources that are located behind a window.
@@ -567,7 +604,9 @@ class MemoryMap:
 		Exceptions
 		----------
 		Raises :exn:`KeyError` if the resource is not found.
+
 		'''
+
 		if id(resource) in self._resources:
 			_, resource_name, resource_range = self._resources[id(resource)]
 			return ResourceInfo(resource, resource_name, resource_range.start, resource_range.stop,
@@ -582,7 +621,8 @@ class MemoryMap:
 		raise KeyError(resource)
 
 	def decode_address(self, address: int) -> Optional[object]:
-		'''Decode an address to a resource.
+		'''
+		Decode an address to a resource.
 
 		Arguments
 		---------
@@ -592,7 +632,9 @@ class MemoryMap:
 		Return value
 		------------
 		A resource mapped to the provided address, or ``None`` if there is no such resource.
+
 		'''
+
 		assignment = self._ranges.get(address)
 		if assignment is None:
 			return
