@@ -1,11 +1,11 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from .bus import *
+from .bus import Arbiter, BurstTypeExt, CycleType, Decoder, Interface
 
 __all__ = (
-	'CycleType',
-	'BurstTypeExt',
-	'Interface',
-	'Decoder',
 	'Arbiter',
+	'BurstTypeExt',
+	'CycleType',
+	'Decoder',
+	'Interface',
 )
