@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 from enum           import Enum
-from typing         import Iterable, Literal, Optional, Tuple
+from typing         import Iterable, Literal, Optional
 
 from ....           import Cat, Elaboratable, Module, Record, Repl, Signal
 from ....hdl.rec    import Direction
@@ -9,16 +9,16 @@ from ....util.units import log2_int
 from ..memory       import MemoryMap
 
 __all__ = (
-	'CycleType',
-	'BurstTypeExt',
-	'Interface',
-	'Decoder',
 	'Arbiter',
+	'BurstTypeExt',
+	'CycleType',
+	'Decoder',
+	'Interface',
 )
 
 
 class CycleType(Enum):
-	'''Wishbone Registered Feedback cycle type.'''
+	''' Wishbone Registered Feedback cycle type. '''
 	CLASSIC      = 0b000
 	CONST_BURST  = 0b001
 	INCR_BURST   = 0b010
@@ -26,7 +26,7 @@ class CycleType(Enum):
 
 
 class BurstTypeExt(Enum):
-	'''Wishbone Registered Feedback burst type extension.'''
+	''' Wishbone Registered Feedback burst type extension. '''
 	LINEAR  = 0b00
 	WRAP_4  = 0b01
 	WRAP_8  = 0b10
@@ -50,7 +50,8 @@ def _check_interface(
 		raise ValueError(f'Optional signal(s) {", ".join(map(repr, unknown))} are not supported')
 
 class Interface(Record):
-	'''Wishbone interface.
+	'''
+	Wishbone interface.
 
 	See the `Wishbone specification <https://opencores.org/howto/wishbone>`_ for description
 	of the Wishbone signals. The ``RST_I`` and ``CLK_I`` signals are provided as a part of
@@ -111,7 +112,9 @@ class Interface(Record):
 		Optional. Corresponds to Wishbone signal ``CTI_O`` (initiator) or ``CTI_I`` (target).
 	bte : Signal()
 		Optional. Corresponds to Wishbone signal ``BTE_O`` (initiator) or ``BTE_I`` (target).
+
 	'''
+
 	def __init__(
 		self, *, addr_width: int, data_width: int, granularity: int = None,
 		features: Iterable[Literal['rty', 'err', 'stall', 'lock', 'cti', 'bte']] = frozenset(),
@@ -180,7 +183,8 @@ class Interface(Record):
 
 
 class Decoder(Elaboratable):
-	'''Wishbone bus decoder.
+	'''
+	Wishbone bus decoder.
 
 	An address decoder for subordinate Wishbone buses.
 
@@ -203,7 +207,9 @@ class Decoder(Elaboratable):
 	----------
 	bus : :class:`Interface`
 		CSR bus providing access to subordinate buses.
+
 	'''
+
 	def __init__(
 		self, *, addr_width: int, data_width: int, granularity: Optional[int] = None,
 		features: Iterable[Literal['rty', 'err', 'stall', 'lock', 'cti', 'bte']] = frozenset(),
@@ -242,17 +248,21 @@ class Decoder(Elaboratable):
 		return self._bus
 
 	def align_to(self, alignment: int) -> int:
-		'''Align the implicit address of the next window.
+		'''
+		Align the implicit address of the next window.
 
 		See :meth:`MemoryMap.align_to` for details.
+
 		'''
+
 		return self._map.align_to(alignment)
 
 	def add(
 		self, sub_bus: Interface, *, addr: Optional[int] = None, sparse: bool = False,
 		extend: bool = False
-	) -> Tuple[int, int, int]:
-		'''Add a window to a subordinate bus.
+	) -> tuple[int, int, int]:
+		'''
+		Add a window to a subordinate bus.
 
 		The decoder can perform either sparse or dense address translation. If dense address
 		translation is used (the default), the subordinate bus must have the same data width as
@@ -262,12 +272,15 @@ class Decoder(Elaboratable):
 		must be equal to or less than the granularity of the decoder.
 
 		See :meth:`MemoryMap.add_resource` for details.
+
 		'''
+
 		if not isinstance(sub_bus, Interface):
 			raise TypeError(f'Subordinate bus must be an instance of wishbone.Interface, not {sub_bus!r}')
 		if sub_bus.granularity > self.granularity:
 			raise ValueError(
-				f'Subordinate bus has granularity {sub_bus.granularity}, which is greater than the decoder granularity {self.granularity}'
+				f'Subordinate bus has granularity {sub_bus.granularity}, which is greater than the decoder '
+				f'granularity {self.granularity}'
 			)
 		if not sparse:
 			if sub_bus.data_width != self.data_width:
@@ -284,7 +297,10 @@ class Decoder(Elaboratable):
 				)
 		for opt_output in { 'err', 'rty', 'stall' }:
 			if hasattr(sub_bus, opt_output) and opt_output not in self.features:
-				raise ValueError(f'Subordinate bus has optional output {opt_output!r}, but the decoder does not have a corresponding input')
+				raise ValueError(
+					f'Subordinate bus has optional output {opt_output!r}, but the decoder does not have '
+					'a corresponding input'
+				)
 
 		self._subs[sub_bus.memory_map] = sub_bus
 		return self._map.add_window(sub_bus.memory_map, addr = addr, sparse = sparse, extend = extend)
@@ -341,7 +357,8 @@ class Decoder(Elaboratable):
 
 
 class Arbiter(Elaboratable):
-	'''Wishbone bus arbiter.
+	'''
+	Wishbone bus arbiter.
 
 	A round-robin arbiter for initiators accessing a shared Wishbone bus.
 
@@ -360,7 +377,9 @@ class Arbiter(Elaboratable):
 	----------
 	bus : :class:`Interface`
 		Shared Wishbone bus.
+
 	'''
+
 	def __init__(
 		self, *, addr_width: int, data_width: int, granularity: Optional[int] = None,
 		features: Iterable[Literal['rty', 'err', 'stall', 'lock', 'cti', 'bte']] = frozenset()
@@ -374,29 +393,38 @@ class Arbiter(Elaboratable):
 		self._intrs = []
 
 	def add(self, intr_bus: Interface) -> None:
-		'''Add an initiator bus to the arbiter.
+		'''
+		Add an initiator bus to the arbiter.
 
 		The initiator bus must have the same address width and data width as the arbiter. The
 		granularity of the initiator bus must be greater than or equal to the granularity of
 		the arbiter.
+
 		'''
+
 		if not isinstance(intr_bus, Interface):
 			raise TypeError(f'Initiator bus must be an instance of wishbone.Interface, not {intr_bus!r}')
 		if intr_bus.addr_width != self.bus.addr_width:
 			raise ValueError(
-				f'Initiator bus has address width {intr_bus.addr_width}, which is not the same as arbiter address width {self.bus.addr_width}'
+				f'Initiator bus has address width {intr_bus.addr_width}, which is not the same as arbiter '
+				f'address width {self.bus.addr_width}'
 			)
 		if intr_bus.granularity < self.bus.granularity:
 			raise ValueError(
-				f'Initiator bus has granularity {intr_bus.granularity}, which is lesser than the arbiter granularity {self.bus.granularity}'
+				f'Initiator bus has granularity {intr_bus.granularity}, which is lesser than the arbiter '
+				f'granularity {self.bus.granularity}'
 			)
 		if intr_bus.data_width != self.bus.data_width:
 			raise ValueError(
-				f'Initiator bus has data width {intr_bus.data_width}, which is not the same as arbiter data width {self.bus.data_width}'
+				f'Initiator bus has data width {intr_bus.data_width}, which is not the same as arbiter '
+				f'data width {self.bus.data_width}'
 			)
 		for opt_output in { 'err', 'rty' }:
 			if hasattr(self.bus, opt_output) and not hasattr(intr_bus, opt_output):
-				raise ValueError(f'Arbiter has optional output {opt_output!r}, but the initiator bus does not have a corresponding input')
+				raise ValueError(
+					f'Arbiter has optional output {opt_output!r}, but the initiator bus does not have '
+					'a corresponding input'
+				)
 
 		self._intrs.append(intr_bus)
 
@@ -409,7 +437,7 @@ class Arbiter(Elaboratable):
 
 		bus_busy = self.bus.cyc
 		if hasattr(self.bus, 'lock'):
-			# If LOCK is not asserted, we also wait for STB to be deasserted before granting bus
+			# If LOCK is not asserted, we also wait for STB to be de-asserted before granting bus
 			# ownership to the next initiator. If we didn't, the next bus owner could receive
 			# an ACK (or ERR, RTY) from the previous transaction when targeting the same
 			# peripheral.
@@ -430,7 +458,7 @@ class Arbiter(Elaboratable):
 			for i, intr_bus in enumerate(self._intrs):
 				m.d.comb += intr_bus.dat_r.eq(self.bus.dat_r)
 				if hasattr(intr_bus, 'stall'):
-					intr_bus_stall = Signal(reset=1)
+					intr_bus_stall = Signal(reset = 1)
 					m.d.comb += intr_bus.stall.eq(intr_bus_stall)
 
 				with m.Case(i):
