@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from typing        import List, Literal, Optional, Tuple, Union
+from typing        import Literal, Optional, Union
 
 from ...           import Cat, Const, Elaboratable, Module, Record, Signal
 from ...util.units import bits_for
@@ -8,9 +8,9 @@ from ..cdc         import FFSynchronizer
 from ..io          import Pin
 
 __all__ = (
+	'AsyncSerial',
 	'AsyncSerialRX',
 	'AsyncSerialTX',
-	'AsyncSerial',
 )
 
 
@@ -43,7 +43,7 @@ def _compute_parity_bit(
 
 def _wire_layout(
 	data_bits: int, parity: Literal['none', 'mark', 'space', 'even', 'odd'] = 'none'
-) -> List[Tuple[str, int]]:
+) -> list[tuple[str, int]]:
 	return [
 		('start',  1),
 		('data',   data_bits),
@@ -53,7 +53,8 @@ def _wire_layout(
 
 
 class AsyncSerialRX(Elaboratable):
-	'''Asynchronous serial receiver.
+	'''
+	Asynchronous serial receiver.
 
 	Parameters
 	----------
@@ -86,7 +87,9 @@ class AsyncSerialRX(Elaboratable):
 		Read acknowledge. Must be held asserted while data can be read out of the receiver.
 	i : Signal, in
 		Serial input. If ``pins`` has been specified, ``pins.rx.i`` drives it.
+
 	'''
+
 	def __init__(
 		self, *, divisor: int, divisor_bits: Optional[int] = None, data_bits: int = 8,
 		parity: Literal['none', 'mark', 'space', 'even', 'odd'] = 'none',
@@ -121,7 +124,7 @@ class AsyncSerialRX(Elaboratable):
 		bitno = Signal(range(len(shreg)))
 
 		if self._pins is not None:
-			m.submodules += FFSynchronizer(self._pins.rx.i, self.i, reset=1)
+			m.submodules += FFSynchronizer(self._pins.rx.i, self.i, reset = 1)
 
 		with m.FSM() as fsm:
 			with m.State('IDLE'):
@@ -163,7 +166,8 @@ class AsyncSerialRX(Elaboratable):
 
 
 class AsyncSerialTX(Elaboratable):
-	'''Asynchronous serial transmitter.
+	'''
+	Asynchronous serial transmitter.
 
 	Parameters
 	----------
@@ -190,7 +194,9 @@ class AsyncSerialTX(Elaboratable):
 		Write strobe. Data gets transmitted when both ``rdy`` and ``ack`` are asserted.
 	o : Signal, out
 		Serial output. If ``pins`` has been specified, it drives ``pins.tx.o``.
+
 	'''
+
 	def __init__(
 		self, *, divisor: int, divisor_bits: Optional[int] = None, data_bits: int = 8,
 		parity  : Literal['none', 'mark', 'space', 'even', 'odd'] = 'none',
@@ -250,7 +256,8 @@ class AsyncSerialTX(Elaboratable):
 
 
 class AsyncSerial(Elaboratable):
-	'''Asynchronous serial transceiver.
+	'''
+	Asynchronous serial transceiver.
 
 	Parameters
 	----------
@@ -273,7 +280,9 @@ class AsyncSerial(Elaboratable):
 		See :class:`AsyncSerialRX`.
 	tx : :class:`AsyncSerialTX`
 		See :class:`AsyncSerialTX`.
+
 	'''
+
 	def __init__(
 		self, *, divisor: int, divisor_bits: Optional[int] = None, **kwargs
 	) -> None:
