@@ -1,25 +1,22 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-from typing   import (
-	Optional, Tuple, Union, Dict, List, Literal
-)
-
-from ...build import *
+from typing   import Literal, Optional, Union
 
+from ...build import Attrs, Pins, Resource, Subsignal
 
 __all__ = (
+	'ButtonResources',
 	'LEDResources',
 	'RGBLEDResource',
-	'ButtonResources',
 	'SwitchResources',
 )
 
 def _SplitResources(
 	*args,
-	pins: Union[str, List[str], Dict[str, str]], invert: bool = False,
-	conn: Optional[Union[Tuple[str, int], int]] = None,
+	pins: Union[str, list[str], dict[str, str]], invert: bool = False,
+	conn: Optional[Union[tuple[str, int], int]] = None,
 	attrs: Optional[Attrs] = None, default_name: str, dir: Literal['i', 'o', 'io']
-) -> List[Resource]:
+) -> list[Resource]:
 
 	if not isinstance(pins, (str, list, dict)):
 		raise TypeError(f'pins is expected to be a \'str\', \'list\', or \'dict\' not {pins!r}')
@@ -41,14 +38,14 @@ def _SplitResources(
 	return resources
 
 
-def LEDResources(*args, **kwargs) -> List[Resource]:
+def LEDResources(*args, **kwargs) -> list[Resource]:
 	return _SplitResources(*args, **kwargs, default_name = 'led', dir = 'o')
 
 
 def RGBLEDResource(
 	*args,
 	r: str, g: str, b: str, invert: bool = False,
-	conn: Optional[Union[Tuple[str, int], int]] = None, attrs: Optional[Attrs] = None
+	conn: Optional[Union[tuple[str, int], int]] = None, attrs: Optional[Attrs] = None
 ) -> Resource:
 
 	ios = []
@@ -63,9 +60,9 @@ def RGBLEDResource(
 	return Resource.family(*args, default_name = 'rgb_led', ios = ios)
 
 
-def ButtonResources(*args, **kwargs) -> List[Resource]:
+def ButtonResources(*args, **kwargs) -> list[Resource]:
 	return _SplitResources(*args, **kwargs, default_name = 'button', dir = 'i')
 
 
-def SwitchResources(*args, **kwargs) -> List[Resource]:
+def SwitchResources(*args, **kwargs) -> list[Resource]:
 	return _SplitResources(*args, **kwargs, default_name = 'switch', dir = 'i')
