@@ -1,5 +1,6 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
+import logging as log
 from functools import wraps
 from math      import ceil
 from os        import getenv
@@ -10,15 +11,14 @@ from unittest  import TestCase
 from ..hdl.ast import Signal
 from ..hdl.ir  import Fragment
 from ..sim     import Settle, Simulator
-from .mock     import MockPlatform
 
 __all__ = (
 	'ToriiTestCase',
-	'sim_test',
 )
 
 class ToriiTestCase(TestCase):
-	'''Torii test case wrapper for pythons unittest library
+	'''
+	Torii test case wrapper for pythons unittest library
 
 	This class wraps the :py:class:`TestCase` class from the `unittest` module
 	from the python standard lib. It has useful methods for testing and simulating
@@ -26,7 +26,7 @@ class ToriiTestCase(TestCase):
 
 	Attributes
 	----------
-	domains : Tuple[Tuple[str, float]]
+	domains : tuple[tuple[str, float], ...]
 		The collection of clock domains and frequencies
 	out_dir : str
 		The test output directory.
@@ -43,7 +43,7 @@ class ToriiTestCase(TestCase):
 	out_dir   = None
 	dut       = None
 	dut_args  = {}
-	platform  = MockPlatform()
+	platform  = None
 
 	def __init__(self, *args, **kwargs) -> None:
 		super().__init__(*args, **kwargs)
@@ -65,7 +65,8 @@ class ToriiTestCase(TestCase):
 		return 1 / freq
 
 	def run_sim(self, *, suffix: Optional[str] = None) -> None:
-		'''Run the simulation
+		'''
+		Run the simulation
 
 		If the environment variable ``TORII_TEST_INHIBIT_VCD``
 		is set, then no VCDs will be generated.
@@ -74,6 +75,7 @@ class ToriiTestCase(TestCase):
 		------------
 		suffix : str
 			The option VCD test case suffix.
+
 		'''
 
 		if getenv('TORII_TEST_INHIBIT_VCD', default = False):
@@ -89,24 +91,26 @@ class ToriiTestCase(TestCase):
 				self.sim.run()
 
 	def setUp(self) -> None:
+		''' Set up the simulator per test-case '''
+		if self.dut is not None:
+			self.dut   = self.init_dut()
+			self._frag = Fragment.get(self.dut, self.platform)
+			self.sim   = Simulator(self._frag)
 
-		self.dut   = self.init_dut()
-		self._frag = Fragment.get(self.dut, self.platform)
-		self.sim   = Simulator(self._frag)
+			if self.out_dir is None:
+				if (Path.cwd() / 'build').exists():
+					self.out_dir = Path.cwd() / 'build' / 'tests'
+				else:
+					self.out_dir = Path.cwd() / 'test-vcds'
 
-		if self.out_dir is None:
-			if (Path.cwd() / 'build').exists():
-				self.out_dir = Path.cwd() / 'build' / 'tests'
-			else:
-				self.out_dir = Path.cwd() / 'test-vcds'
+			self.out_dir.mkdir(exist_ok = True, parents = True)
 
-		self.out_dir.mkdir(exist_ok = True, parents = True)
-
-		for d, _ in self.domains:
-			self.sim.add_clock(self.clk_period(d), domain = d)
+			for d, _ in self.domains:
+				self.sim.add_clock(self.clk_period(d), domain = d)
 
 	def init_dut(self):
 		''' Initialize and return the DUT '''
+
 		return self.dut(**self.dut_args)
 
 	def init_signals(self):
@@ -114,7 +118,8 @@ class ToriiTestCase(TestCase):
 		yield Signal()
 
 	def wait_for(self, time: float, domain: Optional[str] = None):
-		''' Waits for the number time units.
+		'''
+		Waits for the number time units.
 
 		Parameters
 		----------
@@ -129,7 +134,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def pulse(sig: Signal , *, neg: bool = False, post_step: bool = True):
-		'''Pulse a given signal.
+		'''
+		Pulse a given signal.
 
 		Pulse a given signal to 1 then 0, or if `neg` is set to `True` pulse
 		from 1 to 0.
@@ -147,6 +153,7 @@ class ToriiTestCase(TestCase):
 			Insert additional simulation step after pulse.
 
 		'''
+
 		if not neg:
 			yield sig.eq(1)
 			yield
@@ -161,7 +168,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def pulse_pos(sig: Signal, *, post_step: bool = True):
-		'''Inserts a positive pulse on the given signal
+		'''
+		Inserts a positive pulse on the given signal
 
 		Parameters
 		----------
@@ -179,7 +187,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def pulse_neg(sig: Signal, *, post_step: bool = True):
-		'''Inserts a negative pulse on the given signal
+		'''
+		Inserts a negative pulse on the given signal
 
 		Parameters
 		----------
@@ -197,7 +206,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def step(cycles: int):
-		'''Step simulator.
+		'''
+		Step simulator.
 
 		This advances the simulation by the given number of cycles.
 
@@ -213,7 +223,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def settle(count: int = 1):
-		'''Settle simulator.
+		'''
+		Settle simulator.
 
 		This advances the simulation by the given number of settles.
 
@@ -229,7 +240,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def wait_until_high(strobe: Signal, *, timeout: int = None):
-		'''Run simulation until signal goes high.
+		'''
+		Run simulation until signal goes high.
 
 		Runs the simulation while checking for the positive edge of the `strobe`
 		signal.
@@ -259,7 +271,8 @@ class ToriiTestCase(TestCase):
 
 	@staticmethod
 	def wait_until_low(strobe: Signal, *, timeout: int = None):
-		'''Run simulation until signal goes low.
+		'''
+		Run simulation until signal goes low.
 
 		Runs the simulation while checking for the negative edge of the `strobe`
 		signal.
@@ -278,6 +291,7 @@ class ToriiTestCase(TestCase):
 		------------
 		timeout : int
 			The max number of cycles to wait.
+
 		'''
 
 		elapsed_cycles = 0
@@ -287,34 +301,84 @@ class ToriiTestCase(TestCase):
 			if timeout and elapsed_cycles > timeout:
 				raise RuntimeError(f'Timeout waiting for \'{strobe.name}\' to go low')
 
-def sim_test(*, domain: str = None, defer: bool = False):
-	'''Simulation test case decorator
+	@staticmethod
+	def simulation(func):
+		'''
+		Simulation test case decorator
 
-	Parameters
-	----------
-	func
-		The decorated function.
+		..note::
+			This must always be the top-most decorator due to how
+			python decorator precedence works.
 
-	Keyword Args
-	------------
-	domain : str
-		The clock domain this case belongs to.
+		Parameters
+		----------
+		func
+			The decorated function.
 
-	'''
-	def _test(func):
-		def _run(self):
+		'''
+
+		def _run(self: ToriiTestCase):
+			# Invoke the wrapped setup we did
+			func(self)
+
+			log.debug(f'Running simulation for \'{func.__name__}\'')
+			self.run_sim(suffix = func.__name__)
+		return _run
+
+	@staticmethod
+	def sync_domain(*, domain: str):
+		'''
+		This decorator is used to annotate that the following function should be simulated
+		in the specified synchronous domain.
+
+		It should be used in combination with :py:func:`ToriiTestCase.sim_test` to simulate
+		a synchronous process.
+
+		Parameters
+		----------
+		domain : str
+			The domain this process belongs to
+
+		'''
+
+		def _sync(func):
 			@wraps(func)
-			def sim_case():
-				yield from self.init_signals()
+			def _add(self: ToriiTestCase):
+				if domain not in map(lambda d: d[0], self.domains):
+					raise ValueError(
+						f'The requested domain \'{domain}\' was not specified in the ',
+						'test suite.\n'
+						'The following domains are defined:\n',
+						f'{self.domains}'
+					)
+
+
+				def proc():
+					yield from func(self)
+
+				log.debug(f'Adding synchronous process \'{func.__name__}\' to domain \'{domain}\'')
+				self.sim.add_sync_process(proc, domain = domain)
+
+			return _add
+		return _sync
+
+	@staticmethod
+	def comb_domain(func):
+		'''
+		This decorator is used to annotate that the following function should be simulated
+		in the combinatorial domain.
+
+		It should be used in combination with :py:func:`ToriiTestCase.sim_test` to simulate
+		a combinatorial process.
+		'''
+
+		@wraps(func)
+		def _add_comb(self: ToriiTestCase):
+
+			def proc():
 				yield from func(self)
 
-			if domain is None:
-				test_domain = self.domains[0][0]
-			else:
-				test_domain = domain
+			log.debug(f'Adding combinatorial process \'{func.__name__}\'')
+			self.sim.add_process(proc)
 
-			self.sim.add_sync_process(sim_case, domain = test_domain)
-			if not defer:
-				self.run_sim(suffix = func.__name__)
-		return _run
-	return _test
+		return _add_comb
