@@ -3,14 +3,13 @@
 from collections.abc import Iterable
 from linecache       import getlines
 from re              import compile
-from typing          import Dict, Type, Union
-from warnings        import warn_explicit
+from typing          import Union
 
 __all__ = (
 	'flatten',
-	'union',
-	'get_linter_options',
 	'get_linter_option',
+	'get_linter_options',
+	'union',
 )
 
 def flatten(i):
@@ -30,21 +29,13 @@ def union(i, start = None):
 			r |= e
 	return r
 
-def get_linter_options(filename: str) -> Dict[str, Union[int, str]]:
-	# Check the first five lines of the file
-	magic_comments = (
-		compile(r'^#\s*amaranth:\s*((?:\w+=\w+\s*)(?:,\s*\w+=\w+\s*)*)\n$'),
-		compile(r'^#\s*torii:\s*((?:\w+=\w+\s*)(?:,\s*\w+=\w+\s*)*)\n$'),
-	)
+def get_linter_options(filename: str) -> dict[str, Union[int, str]]:
+	magic_comment = compile(r'^#\s*torii:\s*((?:\w+=\w+\s*)(?:,\s*\w+=\w+\s*)*)\n$')
 
+	# Check the first five lines of the file, because it might not be first
 	lines = getlines(filename)[0:5]
 	if len(lines) > 0:
-		matches = list(filter(lambda m: m is not None, map(magic_comments[0].match, lines)))
-		if len(matches) > 0:
-			warn_explicit('Use `# torii:` annotation instead of `# amaranth:`',
-				DeprecationWarning, filename, 1)
-		else:
-			matches = list(filter(lambda m: m is not None, map(magic_comments[1].match, lines)))
+		matches = list(filter(lambda m: m is not None, map(magic_comment.match, lines)))
 
 		if len(matches) > 0:
 			return dict(map(lambda s: s.strip().split('=', 2), matches[0].group(1).split(',')))
@@ -52,7 +43,7 @@ def get_linter_options(filename: str) -> Dict[str, Union[int, str]]:
 
 
 def get_linter_option(
-	filename: str , name: str, type: Union[Type[bool], Type[int]], default: Union[bool, int]
+	filename: str , name: str, type: Union[type[bool], type[int]], default: Union[bool, int]
 ) -> Union[bool, int]:
 	options = get_linter_options(filename)
 	if name not in options:
