@@ -4,8 +4,9 @@ from re import Match, finditer, sub
 
 __all__ = (
 	'ascii_escape',
-	'tcl_quote',
 	'tcl_escape',
+	'tcl_quote',
+	'tool_env_var',
 )
 
 def ascii_escape(string: str) -> str:
@@ -28,4 +29,27 @@ def tcl_escape(string: str) -> str:
 def tcl_quote(string: str) -> str:
 	''' Apply appropriate quoting for use in TCL scripts '''
 
-	return '"' + sub(r'([$[\\])', r'\\\1', string) + '"'
+	return '"' + sub(r'([$[\\"])', r'\\\1', string) + '"'
+
+def tool_env_var(name: str) -> str:
+	'''
+	Convert the given tool name into a normalized version for
+	environment variables.
+
+	This generally means replacing any `-`'s with `_`'s and any
+	`+`'s with `X`'s and converting the entire name to uppercase.
+
+	Parameters
+	----------
+	name : str
+		The tool/executable name.
+
+	Returns
+	-------
+	str
+		The name of the environment variable used to look for
+		for tool overrides.
+
+	'''
+
+	return name.upper().replace('-', '_').replace('+', 'X')
