@@ -1,13 +1,14 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 from sys    import _getframe, version_info
-from typing import Optional, Tuple, Union
+from typing import Optional, Union
+
 from opcode import opname
 
 __all__ = (
-	'NameNotFound',
-	'get_var_name',
 	'get_src_loc',
+	'get_var_name',
+	'NameNotFound',
 )
 
 class NameNotFound(Exception):
@@ -28,7 +29,7 @@ def get_var_name(depth: int = 2, default: Optional[Union[str, object]] = _raise_
 		else:
 			break
 	if call_opc not in ('CALL_FUNCTION', 'CALL_FUNCTION_KW', 'CALL_FUNCTION_EX', 'CALL_METHOD', 'CALL'):
-		return None
+		return default
 
 	index = call_index + 2
 	while True:
@@ -56,7 +57,7 @@ def get_var_name(depth: int = 2, default: Optional[Union[str, object]] = _raise_
 				return default
 
 
-def get_src_loc(src_loc_at: int = 0) -> Tuple[str, int]:
+def get_src_loc(src_loc_at: int = 0) -> tuple[str, int]:
 	# n-th  frame: get_src_loc()
 	# n-1th frame: caller of get_src_loc() (usually constructor)
 	# n-2th frame: caller of caller (usually user code)
