@@ -1,21 +1,28 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 __all__ = (
+	'ps_to_sec',
 	'ns_to_sec',
 	'us_to_sec',
 	'ms_to_sec',
+	'sec_to_ps',
 	'sec_to_ns',
 	'sec_to_us',
 	'sec_to_ms',
+	'bits_for',
 	'iec_size',
 	'log2_int',
-	'bits_for',
 )
 
+PS = 1e-12
 NS = 1e-9
 US = 1e-6
 MS = 1e-3
 
+def ps_to_sec(val: float) -> float:
+	''' Convert the given number of picoseconds into fractional seconds '''
+	return val * PS
+
 def ns_to_sec(val: float) -> float:
 	''' Convert the given number of nanoseconds into fractional seconds '''
 	return val * NS
@@ -28,6 +35,10 @@ def ms_to_sec(val: float) -> float:
 	''' Convert the given number of milliseconds into fractional seconds '''
 	return val * MS
 
+def sec_to_ps(val: float) -> float:
+	''' Convert the give number of sections into picoseconds '''
+	return val / PS
+
 def sec_to_ns(val: float) -> float:
 	''' Convert the give number of sections into nanoseconds '''
 	return val / NS
@@ -55,7 +66,13 @@ def iec_size(size: int, dec: int = 2) -> str:
 
 	scale = int(floor(log(size, 1024)))
 	power = pow(1024, scale)
-	fixed = round((size / power), dec)
+	fixed = size / power
+	rem = size % power
+
+	if rem == 0 and dec == 0:
+		fixed = int(fixed)
+	else:
+		fixed = round(fixed, dec)
 
 	return f'{fixed}{suffixes[scale]}'
 
